@@ -1,6 +1,6 @@
-import arcom.test, arc, unittest
+import testutils, arc, unittest
 
-class EndpointTest(arcom.test.ARCClientTestCase):
+class EndpointTest(testutils.ARCClientTestCase):
 
     def test_the_class_exists(self):
         self.expect(arc.Endpoint).to_be_an_instance_of(type)
@@ -43,7 +43,7 @@ class EndpointTest(arcom.test.ARCClientTestCase):
         
     def test_string_representation(self):
         registry = arc.Endpoint("test.nordugrid.org", ["information.discovery.registry"], "org.nordugrid.sertest")
-        self.expect(registry.str()).to_be("test.nordugrid.org (information.discovery.registry, org.nordugrid.sertest)")
+        self.expect(registry.str()).to_be("test.nordugrid.org (org.nordugrid.sertest, capabilities: information.discovery.registry)")
         
               
 if __name__ == '__main__':
