@@ -138,14 +138,14 @@ int RUNMAIN(arckill)(int argc, char **argv) {
     jobmaster.SelectByID(canceled);
     if(!jobmaster.Clean()) {
       std::cout << Arc::IString("Warning: Some jobs were not removed from server") << std::endl;
-      std::cout << Arc::IString("         Use arclean to remove retrieved jobs from job list", usercfg.JobListFile()) << std::endl;
+      std::cout << Arc::IString("         Use arcclean to remove retrieved jobs from job list", usercfg.JobListFile()) << std::endl;
       retval = 1;
     }
     cleaned_num = jobmaster.GetIDsProcessed().size();
 
     if (!jobstore->Remove(jobmaster.GetIDsProcessed())) {
       std::cout << Arc::IString("Warning: Failed removing jobs from file (%s)", usercfg.JobListFile()) << std::endl;
-      std::cout << Arc::IString("         Run 'arcclean -s Undefined' to remove killed jobs from job list", usercfg.JobListFile()) << std::endl;
+      std::cout << Arc::IString("         Run 'arcclean -s Undefined' to remove killed jobs from job list") << std::endl;
       retval = 1;
     }
     std::cout << Arc::IString("Jobs processed: %d, successfully killed: %d, successfully cleaned: %d", selected_num, canceled_num, cleaned_num) << std::endl;
