@@ -46,7 +46,9 @@ int RUNMAIN(arcstat)(int argc, char **argv) {
 
   // If debug is specified as argument, it should be set before loading the configuration.
   if (!opt.debug.empty())
-    Arc::Logger::getRootLogger().setThreshold(Arc::string_to_level(opt.debug));
+    Arc::Logger::getRootLogger().setThreshold(Arc::istring_to_level(opt.debug));
+
+  logger.msg(Arc::VERBOSE, "Running command: %s", opt.GetCommandWithArguments());
 
   if (opt.show_plugins) {
     std::list<std::string> types;
@@ -62,7 +64,7 @@ int RUNMAIN(arcstat)(int argc, char **argv) {
   }
 
   if (opt.debug.empty() && !usercfg.Verbosity().empty())
-    Arc::Logger::getRootLogger().setThreshold(Arc::string_to_level(usercfg.Verbosity()));
+    Arc::Logger::getRootLogger().setThreshold(Arc::istring_to_level(usercfg.Verbosity()));
 
   for (std::list<std::string>::const_iterator it = opt.jobidinfiles.begin(); it != opt.jobidinfiles.end(); it++) {
     if (!Arc::Job::ReadJobIDsFromFile(*it, jobidentifiers)) {
@@ -134,14 +136,17 @@ int RUNMAIN(arcstat)(int argc, char **argv) {
 
   Arc::JobSupervisor jobmaster(usercfg, jobs);
   jobmaster.Update();
-  jobmaster.SelectValid();
+  unsigned int queried_num = jobmaster.GetAllJobs().size();
   if (!opt.status.empty()) {
     jobmaster.SelectByStatus(opt.status);
   }
+  if (!opt.show_unavailable) {
+    jobmaster.SelectValid();
+  }
   jobs = jobmaster.GetSelectedJobs();
 
-  if (jobs.empty()) {
-    std::cout << Arc::IString("No jobs") << std::endl;
+  if (queried_num == 0) {
+    std::cout << Arc::IString("No jobs found, try later") << std::endl;
     return 1;
   }
 
@@ -163,5 +168,12 @@ int RUNMAIN(arcstat)(int argc, char **argv) {
     }
   }
 
+  if (opt.show_unavailable) {
+    jobmaster.SelectValid();
+  }
+  unsigned int returned_info_num = jobmaster.GetSelectedJobs().size();
+
+  std::cout << Arc::IString("Status of %d jobs was queried, %d jobs returned information", queried_num, returned_info_num) << std::endl;
+
   return 0;
 }
