@@ -14,6 +14,31 @@
 
 #include "utils.h"
 
+#ifndef WIN32
+
+#include <unistd.h>
+#include <termios.h>
+
+ConsoleRecovery::ConsoleRecovery(void) {
+  ti = new termios;
+  if (tcgetattr(STDIN_FILENO, ti) == 0) return;
+  delete ti;
+  ti = NULL;
+}
+
+ConsoleRecovery::~ConsoleRecovery(void) {
+  if(ti) tcsetattr(STDIN_FILENO, TCSANOW, ti);
+  delete ti;
+}
+
+#else
+
+ConsoleRecovery::ConsoleRecovery(void) { }
+
+ConsoleRecovery::~ConsoleRecovery(void) { }
+
+#endif
+
 std::list<std::string> getSelectedURLsFromUserConfigAndCommandLine(Arc::UserConfig usercfg, std::list<std::string> computingelements) {
   std::list<Arc::Endpoint> endpoints = getServicesFromUserConfigAndCommandLine(usercfg, std::list<std::string>(), computingelements);
   std::list<std::string> serviceURLs;
