@@ -9,6 +9,7 @@
 
 #include <unistd.h>
 #include <sys/types.h>
+#include <signal.h>
 
 #include <arc/ArcLocation.h>
 #include <arc/GUID.h>
@@ -26,6 +27,16 @@
 #include <arc/OptionParser.h>
 
 static Arc::Logger logger(Arc::Logger::getRootLogger(), "arccp");
+static Arc::SimpleCondition cond;
+static bool cancelled = false;
+
+static void sig_cancel(int)
+{
+  if (cancelled) _exit(0);
+  cancelled = true;
+  cond.broadcast();
+}
+
 
 static void progress(FILE *o, const char*, unsigned int,
                      unsigned long long int all, unsigned long long int max,
@@ -54,13 +65,44 @@ static void progress(FILE *o, const char*, unsigned int,
   fprintf(o, "\r%llu kB                    \r", all / 1024);
 }
 
-bool arcregister(const Arc::URL& source_url,
+static void transfer_cb(unsigned long long int bytes_transferred) {
+  fprintf (stderr, "\r%llu kB                  \r", bytes_transferred / 1024);
+}
+
+
+static void mover_callback(Arc::DataMover* mover, Arc::DataStatus status, void* arg) {
+  Arc::DataStatus* res = (Arc::DataStatus*)arg;
+  *res = status;
+  if (!res->Passed()) {
+    logger.msg(Arc::ERROR, "Current transfer FAILED: %s", std::string(*res));
+    if (res->Retryable()) {
+      logger.msg(Arc::ERROR, "This seems like a temporary error, please try again later");
+    }
+  }
+  cond.broadcast();
+}
+
+static bool checkProxy(const Arc::UserConfig& usercfg, const Arc::URL& src_file) {
+  if (usercfg.ProxyPath().empty() ) {
+    logger.msg(Arc::ERROR, "Unable to copy %s: No valid credentials found", src_file.str());
+    return false;
+  }
+  Arc::Credential holder(usercfg.ProxyPath(), "", "", "");
+  if (holder.GetEndTime() < Arc::Time()){
+    logger.msg(Arc::ERROR, "Proxy expired");
+    logger.msg(Arc::ERROR, "Unable to copy %s: No valid credentials found", src_file.str());
+    return false;
+  }
+  return true;
+}
+
+bool arctransfer(const Arc::URL& source_url,
                  const Arc::URL& destination_url,
                  const std::list<std::string>& locations,
                  Arc::UserConfig& usercfg,
                  bool secure,
                  bool passive,
-                 bool force_meta,
+                 bool verbose,
                  int timeout) {
   if (!source_url) {
     logger.msg(Arc::ERROR, "Invalid URL: %s", source_url.str());
@@ -70,6 +112,43 @@ bool arcregister(const Arc::URL& source_url,
     logger.msg(Arc::ERROR, "Invalid URL: %s", destination_url.str());
     return false;
   }
+  // Credentials are always required for 3rd party transfer
+  if (!checkProxy(usercfg, source_url)) return false;
+  if (timeout > 0) usercfg.Timeout(timeout);
+
+  Arc::DataStatus res = Arc::DataPoint::Transfer3rdParty(source_url, destination_url, usercfg, verbose ? &transfer_cb : NULL);
+  if (verbose) std::cerr<<std::endl;
+
+  if (!res) {
+    if (res == Arc::DataStatus::UnimplementedError) {
+      logger.msg(Arc::ERROR, "Third party transfer is not supported for these endpoints");
+    } else if (res.GetErrno() == EPROTONOSUPPORT) {
+      logger.msg(Arc::ERROR, "Protocol(s) not supported - please check that the relevant gfal2\n"
+                      "       plugins are installed (gfal2-plugin-* packages)");
+    } else {
+      logger.msg(Arc::ERROR, "Transfer FAILED: %s", std::string(res));
+      if (res.Retryable()) {
+        logger.msg(Arc::ERROR, "This seems like a temporary error, please try again later");
+      }
+    }
+    return false;
+  }
+  return true;
+}
+
+
+bool arcregister(const Arc::URL& source_url,
+                 const Arc::URL& destination_url,
+                 Arc::UserConfig& usercfg,
+                 bool force_meta) {
+  if (!source_url) {
+    logger.msg(Arc::ERROR, "Invalid URL: %s", source_url.str());
+    return false;
+  }
+  if (!destination_url) {
+    logger.msg(Arc::ERROR, "Invalid URL: %s", destination_url.str());
+    return false;
+  }
   if (source_url.Protocol() == "urllist" &&
       destination_url.Protocol() == "urllist") {
     std::list<Arc::URL> sources = Arc::ReadURLList(source_url);
@@ -85,17 +164,17 @@ bool arcregister(const Arc::URL& source_url,
       return false;
     }
     if (sources.size() != destinations.size()) {
-      logger.msg(Arc::ERROR,
-                 "Numbers of sources and destinations do not match");
+      logger.msg(Arc::ERROR, "Numbers of sources and destinations do not match");
       return false;
     }
     bool r = true;
     for (std::list<Arc::URL>::iterator source = sources.begin(),
                                        destination = destinations.begin();
          (source != sources.end()) && (destination != destinations.end());
-         source++, destination++)
-      if(!arcregister(*source, *destination, locations, usercfg, secure, passive,
-                      force_meta, timeout)) r = false;
+         source++, destination++) {
+      if (!arcregister(*source, *destination, usercfg, force_meta)) r = false;
+      if (cancelled) return true;
+    }
     return r;
   }
   if (source_url.Protocol() == "urllist") {
@@ -107,9 +186,10 @@ bool arcregister(const Arc::URL& source_url,
     }
     bool r = true;
     for (std::list<Arc::URL>::iterator source = sources.begin();
-         source != sources.end(); source++)
-      if(!arcregister(*source, destination_url, locations, usercfg, secure, passive,
-                      force_meta, timeout)) r = false;
+         source != sources.end(); source++) {
+      if (!arcregister(*source, destination_url, usercfg, force_meta)) r = false;
+      if (cancelled) return true;
+    }
     return r;
   }
   if (destination_url.Protocol() == "urllist") {
@@ -121,9 +201,10 @@ bool arcregister(const Arc::URL& source_url,
     }
     bool r = true;
     for (std::list<Arc::URL>::iterator destination = destinations.begin();
-         destination != destinations.end(); destination++)
-      if(!arcregister(source_url, *destination, locations, usercfg, secure, passive,
-                      force_meta, timeout)) r = false;
+         destination != destinations.end(); destination++) {
+      if (!arcregister(source_url, *destination, usercfg, force_meta)) r = false;
+      if (cancelled) return true;
+    }
     return r;
   }
 
@@ -131,13 +212,6 @@ bool arcregister(const Arc::URL& source_url,
     logger.msg(Arc::ERROR, "Fileset registration is not supported yet");
     return false;
   }
-  if (source_url.IsSecureProtocol() || destination_url.IsSecureProtocol()) {
-    usercfg.InitializeCredentials(Arc::initializeCredentialsType::RequireCredentials);
-    if (!Arc::Credential::IsCredentialsValid(usercfg)) {
-      logger.msg(Arc::ERROR, "Unable to register file %s: No valid credentials found", source_url.str());
-      return false;
-    }
-  }
   Arc::DataHandle source(source_url, usercfg);
   Arc::DataHandle destination(destination_url, usercfg);
   if (!source) {
@@ -145,67 +219,124 @@ bool arcregister(const Arc::URL& source_url,
     return false;
   }
   if (!destination) {
-    logger.msg(Arc::ERROR, "Unsupported destination url: %s",
-               destination_url.str());
+    logger.msg(Arc::ERROR, "Unsupported destination url: %s", destination_url.str());
     return false;
   }
+  if ((source->RequiresCredentials() || destination->RequiresCredentials())
+      && !checkProxy(usercfg, source_url)) return false;
+
   if (source->IsIndex() || !destination->IsIndex()) {
     logger.msg(Arc::ERROR, "For registration source must be ordinary URL"
                " and destination must be indexing service");
     return false;
   }
-  if (!locations.empty()) {
-    std::string meta(destination->GetURL().Protocol()+"://"+destination->GetURL().Host());
-    for (std::list<std::string>::const_iterator i = locations.begin(); i != locations.end(); ++i)
-      destination->AddLocation(*i, meta);
-  }
+
   // Obtain meta-information about source
   Arc::FileInfo fileinfo;
   Arc::DataPoint::DataPointInfoType verb = (Arc::DataPoint::DataPointInfoType)Arc::DataPoint::INFO_TYPE_CONTENT;
-  if (!source->Stat(fileinfo, verb)) {
-    logger.msg(Arc::ERROR, "Source probably does not exist");
+  Arc::DataStatus res = source->Stat(fileinfo, verb);
+  if (!res) {
+    logger.msg(Arc::ERROR, "Could not obtain information about source: %s", std::string(res));
     return false;
   }
-  // add new location
-  if (!destination->Resolve(false)) {
-    logger.msg(Arc::ERROR, "Problems resolving destination");
-    return false;
+  // Check if destination is already registered
+  if (destination->Resolve(true)) {
+    // Check meta-info matches source
+    if (!destination->CompareMeta(*source) && !force_meta) {
+      logger.msg(Arc::ERROR, "Metadata of source does not match existing "
+          "destination. Use the --force option to override this.");
+      return false;
+    }
+    // Remove existing locations
+    destination->ClearLocations();
   }
   bool replication = destination->Registered();
   destination->SetMeta(*source); // pass metadata
-  std::string metaname;
-  // look for similar destination
-  for (destination->SetTries(1); destination->LocationValid();
-       destination->NextLocation()) {
-    const Arc::URL& loc_url = destination->CurrentLocation();
-    if (loc_url == source_url) {
-      metaname = destination->CurrentLocationMetadata();
-      break;
-    }
-  }
-  // remove locations if exist
-  for (destination->SetTries(1); destination->RemoveLocation();) {}
-  // add new location
-  if (metaname.empty())
-    metaname = source_url.ConnectionURL();
+  // Add new location
+  std::string metaname = source_url.ConnectionURL();
   if (!destination->AddLocation(source_url, metaname)) {
-    destination->PreUnregister(replication);
     logger.msg(Arc::ERROR, "Failed to accept new file/destination");
     return false;
   }
   destination->SetTries(1);
-  if (!destination->PreRegister(replication, force_meta)) {
-    logger.msg(Arc::ERROR, "Failed to register new file/destination");
+  res = destination->PreRegister(replication, force_meta);
+  if (!res) {
+    logger.msg(Arc::ERROR, "Failed to register new file/destination: %s", std::string(res));
     return false;
   }
-  if (!destination->PostRegister(replication)) {
+  res = destination->PostRegister(replication);
+  if (!res) {
     destination->PreUnregister(replication);
-    logger.msg(Arc::ERROR, "Failed to register new file/destination");
+    logger.msg(Arc::ERROR, "Failed to register new file/destination: %s", std::string(res));
     return false;
   }
   return true;
 }
 
+static Arc::DataStatus do_mover(const Arc::URL& s_url,
+                                const Arc::URL& d_url,
+                                const std::list<std::string>& locations,
+                                const std::string& cache_dir,
+                                Arc::UserConfig& usercfg,
+                                bool secure,
+                                bool passive,
+                                bool force_meta,
+                                int tries,
+                                bool verbose,
+                                int timeout) {
+
+  Arc::DataHandle source(s_url, usercfg);
+  Arc::DataHandle destination(d_url, usercfg);
+  if (!source) {
+    logger.msg(Arc::ERROR, "Unsupported source url: %s", s_url.str());
+    return Arc::DataStatus::ReadAcquireError;
+  }
+  if (!destination) {
+    logger.msg(Arc::ERROR, "Unsupported destination url: %s", d_url.str());
+    return Arc::DataStatus::WriteAcquireError;
+  }
+  if ((source->RequiresCredentials() || destination->RequiresCredentials())
+      && !checkProxy(usercfg, s_url)) return Arc::DataStatus::CredentialsExpiredError;
+
+  if (!locations.empty()) {
+    std::string meta(destination->GetURL().Protocol()+"://"+destination->GetURL().Host());
+    for (std::list<std::string>::const_iterator i = locations.begin(); i != locations.end(); ++i) {
+      destination->AddLocation(*i, meta);
+    }
+  }
+  Arc::DataMover mover;
+  mover.secure(secure);
+  mover.passive(passive);
+  mover.verbose(verbose);
+  mover.force_to_meta(force_meta);
+  if (tries) {
+    mover.retry(true); // go through all locations
+    source->SetTries(tries); // try all locations "tries" times
+    destination->SetTries(tries);
+  }
+  Arc::User cache_user;
+  Arc::FileCache cache;
+  if (!cache_dir.empty()) cache = Arc::FileCache(cache_dir+" .", "", cache_user.get_uid(), cache_user.get_gid());
+  if (verbose) mover.set_progress_indicator(&progress);
+
+  Arc::DataStatus callback_res;
+  Arc::DataStatus res = mover.Transfer(*source, *destination, cache, Arc::URLMap(),
+                                       0, 0, 0, timeout, &mover_callback, &callback_res);
+  if (!res.Passed()) {
+    logger.msg(Arc::ERROR, "Current transfer FAILED: %s", std::string(res));
+    if (res.Retryable()) {
+      logger.msg(Arc::ERROR, "This seems like a temporary error, please try again later");
+    }
+    return res;
+  }
+  cond.wait(); // wait for mover_callback
+
+  if (verbose) std::cerr<<std::endl;
+  if (cache) cache.Release();
+
+  return callback_res;
+}
+
 bool arccp(const Arc::URL& source_url_,
            const Arc::URL& destination_url_,
            const std::list<std::string>& locations,
@@ -229,10 +360,8 @@ bool arccp(const Arc::URL& source_url_,
     return false;
   }
 
-  if (timeout <= 0)
-    timeout = 300; // 5 minute default
-  if (tries < 0)
-    tries = 0;
+  if (timeout <= 0) timeout = 300; // 5 minute default
+  if (tries < 0) tries = 0;
   if (source_url.Protocol() == "urllist" &&
       destination_url.Protocol() == "urllist") {
     std::list<Arc::URL> sources = Arc::ReadURLList(source_url);
@@ -256,9 +385,11 @@ bool arccp(const Arc::URL& source_url_,
     for (std::list<Arc::URL>::iterator source = sources.begin(),
                                        destination = destinations.begin();
          (source != sources.end()) && (destination != destinations.end());
-         source++, destination++)
-      if(!arccp(*source, *destination, locations, cache_dir, usercfg, secure, passive,
-                force_meta, recursion, tries, verbose, timeout)) r = false;
+         source++, destination++) {
+      if (!arccp(*source, *destination, locations, cache_dir, usercfg, secure, passive,
+                 force_meta, recursion, tries, verbose, timeout)) r = false;
+      if (cancelled) return true;
+    }
     return r;
   }
   if (source_url.Protocol() == "urllist") {
@@ -270,10 +401,11 @@ bool arccp(const Arc::URL& source_url_,
     }
     bool r = true;
     for (std::list<Arc::URL>::iterator source = sources.begin();
-         source != sources.end(); source++)
-      if(!arccp(*source, destination_url, locations, cache_dir, usercfg, secure,
-                passive, force_meta, recursion, tries, verbose, timeout))
-        r = false;
+         source != sources.end(); source++) {
+      if (!arccp(*source, destination_url, locations, cache_dir, usercfg, secure,
+                 passive, force_meta, recursion, tries, verbose, timeout)) r = false;
+      if (cancelled) return true;
+    }
     return r;
   }
   if (destination_url.Protocol() == "urllist") {
@@ -285,15 +417,17 @@ bool arccp(const Arc::URL& source_url_,
     }
     bool r = true;
     for (std::list<Arc::URL>::iterator destination = destinations.begin();
-         destination != destinations.end(); destination++)
-      if(!arccp(source_url, *destination, locations, cache_dir, usercfg, secure,
-                passive, force_meta, recursion, tries, verbose, timeout))
-        r = false;
+         destination != destinations.end(); destination++) {
+      if (!arccp(source_url, *destination, locations, cache_dir, usercfg, secure,
+                 passive, force_meta, recursion, tries, verbose, timeout)) r = false;
+      if (cancelled) return true;
+    }
     return r;
   }
 
   if (destination_url.Path()[destination_url.Path().length() - 1] != '/') {
-    if (source_url.Path()[source_url.Path().length() - 1] == '/') {
+    if (source_url.Path()[source_url.Path().length() - 1] == '/' &&
+        source_url.MetaDataOption("guid").empty()) { // files specified by guid may have path '/'
       logger.msg(Arc::ERROR,
                  "Fileset copy to single object is not supported yet");
       return false;
@@ -313,99 +447,38 @@ bool arccp(const Arc::URL& source_url_,
     }
     else {
       // Fileset copy
-      // Find out if source can be listed (TODO - through datapoint)
-      if ((source_url.Protocol() != "rc") &&
-          (source_url.Protocol() != "rls") &&
-          (source_url.Protocol() != "fireman") &&
-          (source_url.Protocol() != "file") &&
-          (source_url.Protocol() != "se") &&
-          (source_url.Protocol() != "srm") &&
-          (source_url.Protocol() != "lfc") &&
-          (source_url.Protocol() != "gsiftp") &&
-          (source_url.Protocol() != "ftp")) {
-        logger.msg(Arc::ERROR,
-                   "Fileset copy for this kind of source is not supported");
-        return false;
-      }
-      if (source_url.IsSecureProtocol() || destination_url.IsSecureProtocol()) {
-        usercfg.InitializeCredentials(Arc::initializeCredentialsType::RequireCredentials);
-        if (!Arc::Credential::IsCredentialsValid(usercfg)) {
-          logger.msg(Arc::ERROR, "Unable to copy file %s: No valid credentials found", source_url.str());
-          return false;
-        }
-      }
       Arc::DataHandle source(source_url, usercfg);
       if (!source) {
         logger.msg(Arc::ERROR, "Unsupported source url: %s", source_url.str());
         return false;
       }
+      if (source->RequiresCredentials() && !checkProxy(usercfg, source_url)) return false;
+
       std::list<Arc::FileInfo> files;
-      if (source->IsIndex()) {
-        if (!source->List(files, (Arc::DataPoint::DataPointInfoType)
-                  (Arc::DataPoint::INFO_TYPE_NAME | Arc::DataPoint::INFO_TYPE_TYPE))) {
-          logger.msg(Arc::ERROR, "Failed listing metafiles");
-          return false;
-        }
+      Arc::DataStatus result = source->List(files, (Arc::DataPoint::DataPointInfoType)
+                                           (Arc::DataPoint::INFO_TYPE_NAME | Arc::DataPoint::INFO_TYPE_TYPE));
+      if (!result.Passed()) {
+        logger.msg(Arc::ERROR, "%s. Cannot copy fileset", std::string(result));
+        return false;
       }
-      else
-        if (!source->List(files, (Arc::DataPoint::DataPointInfoType)
-                  (Arc::DataPoint::INFO_TYPE_NAME | Arc::DataPoint::INFO_TYPE_TYPE))) {
-          logger.msg(Arc::ERROR, "Failed listing files");
-          return false;
-        }
       bool failures = false;
       // Handle transfer of files first (treat unknown like files)
       for (std::list<Arc::FileInfo>::iterator i = files.begin();
            i != files.end(); i++) {
         if ((i->GetType() != Arc::FileInfo::file_type_unknown) &&
-            (i->GetType() != Arc::FileInfo::file_type_file))
-          continue;
+            (i->GetType() != Arc::FileInfo::file_type_file)) continue;
+
         logger.msg(Arc::INFO, "Name: %s", i->GetName());
         Arc::URL s_url(std::string(source_url.str() + i->GetName()));
         Arc::URL d_url(std::string(destination_url.str() + i->GetName()));
         logger.msg(Arc::INFO, "Source: %s", s_url.str());
         logger.msg(Arc::INFO, "Destination: %s", d_url.str());
-        Arc::DataHandle source(s_url, usercfg);
-        Arc::DataHandle destination(d_url, usercfg);
-        if (!source) {
-          logger.msg(Arc::INFO, "Unsupported source url: %s", s_url.str());
-          continue;
-        }
-        if (!destination) {
-          logger.msg(Arc::INFO, "Unsupported destination url: %s", d_url.str());
-          continue;
-        }
-        if (!locations.empty() && destination->IsIndex()) {
-          std::string meta(destination->GetURL().Protocol()+"://"+destination->GetURL().Host());
-          for (std::list<std::string>::const_iterator i = locations.begin(); i != locations.end(); ++i)
-            destination->AddLocation(*i, meta);
-        }
-        Arc::DataMover mover;
-        mover.secure(secure);
-        mover.passive(passive);
-        mover.verbose(verbose);
-        mover.force_to_meta(force_meta);
-        if (tries) {
-          mover.retry(true); // go through all locations
-          source->SetTries(tries); // try all locations "tries" times
-          destination->SetTries(tries);
-        }
-        Arc::User cache_user;
-        Arc::FileCache cache;
-        if (!cache_dir.empty()) cache = Arc::FileCache(cache_dir+" .", "", cache_user.get_uid(), cache_user.get_gid());
-        Arc::DataStatus res = mover.Transfer(*source, *destination, cache, Arc::URLMap(),
-                                             0, 0, 0, timeout);
-        if (!res.Passed()) {
-          if (!res.GetDesc().empty())
-            logger.msg(Arc::INFO, "Current transfer FAILED: %s - %s", std::string(res), res.GetDesc());
-          else
-            logger.msg(Arc::INFO, "Current transfer FAILED: %s", std::string(res));
-          if (res.Retryable())
-            logger.msg(Arc::ERROR, "This seems like a temporary error, please try again later");
-          failures = true;
-        }
-        else
-          logger.msg(Arc::INFO, "Current transfer complete");
+
+        Arc::DataStatus res = do_mover(s_url, d_url, locations, cache_dir, usercfg, secure, passive,
+                                       force_meta, tries, verbose, timeout);
+        if (cancelled) return true;
+        if (!res.Passed()) failures = true;
+        else logger.msg(Arc::INFO, "Current transfer complete");
       }
       if (failures) {
         logger.msg(Arc::ERROR, "Some transfers failed");
@@ -417,75 +490,27 @@ bool arccp(const Arc::URL& source_url_,
         // Handle directories recursively
         for (std::list<Arc::FileInfo>::iterator i = files.begin();
              i != files.end(); i++) {
-          if (i->GetType() != Arc::FileInfo::file_type_dir)
-            continue;
-          if (verbose)
-            logger.msg(Arc::INFO, "Directory: %s", i->GetName());
+          if (i->GetType() != Arc::FileInfo::file_type_dir) continue;
+          if (verbose) logger.msg(Arc::INFO, "Directory: %s", i->GetName());
           std::string s_url(source_url.str());
           std::string d_url(destination_url.str());
           s_url += i->GetName();
           d_url += i->GetName();
           s_url += "/";
           d_url += "/";
-          if(!arccp(s_url, d_url, locations, cache_dir, usercfg, secure, passive,
-                    force_meta, recursion - 1, tries, verbose, timeout))
-            r = false;
+          if (!arccp(s_url, d_url, locations, cache_dir, usercfg, secure, passive,
+                     force_meta, recursion - 1, tries, verbose, timeout)) r = false;
+          if (cancelled) return true;
         }
       return r;
     }
   }
-  if (source_url.IsSecureProtocol() || destination_url.IsSecureProtocol()) {
-    usercfg.InitializeCredentials(Arc::initializeCredentialsType::RequireCredentials);
-    if (!Arc::Credential::IsCredentialsValid(usercfg)) {
-      logger.msg(Arc::ERROR, "Unable to copy file %s: No valid credentials found", source_url.str());
-      return false;
-    }
-  }
-  Arc::DataHandle source(source_url, usercfg);
-  Arc::DataHandle destination(destination_url, usercfg);
-  if (!source) {
-    logger.msg(Arc::ERROR, "Unsupported source url: %s", source_url.str());
-    return false;
-  }
-  if (!destination) {
-    logger.msg(Arc::ERROR, "Unsupported destination url: %s",
-               destination_url.str());
-    return false;
-  }
-  if (!locations.empty() && destination->IsIndex()) {
-    std::string meta(destination->GetURL().Protocol()+"://"+destination->GetURL().Host());
-    for (std::list<std::string>::const_iterator i = locations.begin(); i != locations.end(); ++i)
-      destination->AddLocation(*i, meta);
-  }
-  Arc::DataMover mover;
-  mover.secure(secure);
-  mover.passive(passive);
-  mover.verbose(verbose);
-  mover.force_to_meta(force_meta);
-  if (tries) { // 0 means default behavior
-    mover.retry(true); // go through all locations
-    source->SetTries(tries); // try all locations "tries" times
-    destination->SetTries(tries);
-  }
-  Arc::FileCache cache;
-  Arc::User cache_user;
-  std::string job_id(Arc::UUID());
-  // always copy to destination rather than link
-  if (!cache_dir.empty()) cache = Arc::FileCache(cache_dir+" .", job_id, cache_user.get_uid(), cache_user.get_gid());
-  if (verbose)
-    mover.set_progress_indicator(&progress);
-  Arc::DataStatus res = mover.Transfer(*source, *destination, cache, Arc::URLMap(),
-                                       0, 0, 0, timeout);
-  if (verbose) std::cerr<<std::endl;
-  // clean up joblinks created during cache procedure
-  if (cache)
-    cache.Release();
-  if (!res.Passed()) {
-    logger.msg(Arc::ERROR, "Transfer FAILED: %s", std::string(res));
-    if (res.Retryable())
-      logger.msg(Arc::ERROR, "This seems like a temporary error, please try again later");
-    return false;
-  }
+
+  Arc::DataStatus res = do_mover(source_url, destination_url, locations, cache_dir, usercfg, secure, passive,
+                                 force_meta, tries, verbose, timeout);
+  if (cancelled) return true;
+  if (!res.Passed()) return false;
+
   logger.msg(Arc::INFO, "Transfer complete");
   return true;
 }
@@ -494,6 +519,10 @@ int main(int argc, char **argv) {
 
   setlocale(LC_ALL, "");
 
+  // set signal handlers for safe cancellation
+  signal(SIGTERM, sig_cancel);
+  signal(SIGINT, sig_cancel);
+
   Arc::LogStream logcerr(std::cerr);
   logcerr.setFormat(Arc::ShortFormat);
   Arc::Logger::getRootLogger().addDestination(logcerr);
@@ -536,8 +565,8 @@ int main(int argc, char **argv) {
 
   bool nocopy = false;
   options.AddOption('T', "notransfer",
-                    istring("do not transfer file, just register it - "
-                            "destination must be non-existing meta-url"),
+                    istring("do not transfer, but register source into "
+                            "destination. destination must be a meta-url."),
                     nocopy);
 
   bool secure = false;
@@ -550,8 +579,13 @@ int main(int argc, char **argv) {
                     istring("path to local cache (use to put file into cache)"),
                     istring("path"), cache_path);
 
-  int recursion = 0;
+  bool infinite_recursion = false;
   options.AddOption('r', "recursive",
+                    istring("operate recursively"),
+                    infinite_recursion);
+
+  int recursion = 0;
+  options.AddOption('D', "depth",
                     istring("operate recursively up to specified level"),
                     istring("level"), recursion);
 
@@ -568,6 +602,12 @@ int main(int argc, char **argv) {
                             " locations will be tried in order until one succeeds."),
                     istring("URL"), locations);
 
+  bool thirdparty = false;
+  options.AddOption('3', "thirdparty",
+                    istring("perform third party transfer, where the destination pulls"
+                            " from the source (only available with GFAL plugin)"),
+                    thirdparty);
+
   bool show_plugins = false;
   options.AddOption('P', "listplugins",
                     istring("list the available plugins (protocols supported)"),
@@ -599,8 +639,9 @@ int main(int argc, char **argv) {
   }
 
   // If debug is specified as argument, it should be set before loading the configuration.
-  if (!debug.empty())
-    Arc::Logger::getRootLogger().setThreshold(Arc::string_to_level(debug));
+  if (!debug.empty()) Arc::Logger::getRootLogger().setThreshold(Arc::istring_to_level(debug));
+
+  logger.msg(Arc::VERBOSE, "Running command: %s", options.GetCommandWithArguments());
 
   if (show_plugins) {
     std::list<Arc::ModuleDesc> modules;
@@ -619,16 +660,18 @@ int main(int argc, char **argv) {
     return 0;
   }
 
-  // credentials will be initialised later if necessary
-  Arc::UserConfig usercfg(conffile, Arc::initializeCredentialsType::SkipCredentials);
+  // Attempt to acquire credentials. Whether they are required will be
+  // determined later depending on the protocol.
+  Arc::UserConfig usercfg(conffile, Arc::initializeCredentialsType::TryCredentials);
   if (!usercfg) {
     logger.msg(Arc::ERROR, "Failed configuration initialization");
     return 1;
   }
   usercfg.UtilsDirPath(Arc::UserConfig::ARCUSERDIRECTORY);
 
-  if (debug.empty() && !usercfg.Verbosity().empty())
-    Arc::Logger::getRootLogger().setThreshold(Arc::string_to_level(usercfg.Verbosity()));
+  if (debug.empty() && !usercfg.Verbosity().empty()) {
+    Arc::Logger::getRootLogger().setThreshold(Arc::istring_to_level(usercfg.Verbosity()));
+  }
 
   if (params.size() != 2) {
     logger.msg(Arc::ERROR, "Wrong number of parameters specified");
@@ -640,8 +683,8 @@ int main(int argc, char **argv) {
     return 1;
   }
 
-  if ((!secure) && (!notpassive))
-    passive = true;
+  if ((!secure) && (!notpassive)) passive = true;
+  if (infinite_recursion) recursion = INT_MAX;
 
   std::list<std::string>::iterator it = params.begin();
   std::string source = *it;
@@ -650,13 +693,14 @@ int main(int argc, char **argv) {
 
   if (source == "-") source = "stdio:///stdin";
   if (destination == "-") destination = "stdio:///stdout";
-  if (nocopy) {
-    if(!arcregister(source, destination, locations, usercfg, secure, passive, force, timeout))
-      return 1;
+
+  if (thirdparty) {
+    if (!arctransfer(source, destination, locations, usercfg, secure, passive, verbose, timeout)) return 1;
+  } else if (nocopy) {
+    if (!arcregister(source, destination, usercfg, force)) return 1;
   } else {
-    if(!arccp(source, destination, locations, cache_path, usercfg, secure, passive, force,
-          recursion, retries + 1, verbose, timeout))
-      return 1;
+    if (!arccp(source, destination, locations, cache_path, usercfg, secure, passive, force,
+               recursion, retries + 1, verbose, timeout)) return 1;
   }
 
   return 0;
