@@ -21,47 +21,10 @@ namespace Arc {
     return pos != std::string::npos && lower(endpoint.URLString.substr(0, pos)) != "http" && lower(endpoint.URLString.substr(0, pos)) != "https";
   }
 
-  static URL CreateURL(std::string str) {
-    std::string::size_type pos1 = str.find("://");
-    if (pos1 == std::string::npos) {
-      str = "https://" + str;
-      pos1 = 5;
-    } else {
-      if(lower(str.substr(0,pos1)) != "https" && lower(str.substr(0,pos1)) != "http" ) return URL();
-    }
-    std::string::size_type pos2 = str.find(":", pos1 + 3);
-    std::string::size_type pos3 = str.find("/", pos1 + 3);
-    if (pos3 == std::string::npos && pos2 == std::string::npos) str += ":8443";
-    else if (pos2 == std::string::npos || pos2 > pos3) str.insert(pos3, ":8443");
-
-    return str;
-  }
-
-  static URL CreateInfoURL(std::string str) {
-    std::string::size_type pos1 = str.find("://");
-    if (pos1 == std::string::npos) {
-      str = "ldap://" + str;
-      pos1 = 4;
-    } else {
-      if(lower(str.substr(0,pos1)) != "ldap") return URL();
-    }
-    std::string::size_type pos2 = str.find(":", pos1 + 3);
-    std::string::size_type pos3 = str.find("/", pos1 + 3);
-    if (pos3 == std::string::npos) {
-      if (pos2 == std::string::npos) str += ":2170";
-      str += "/o=grid";
-    }
-    else if (pos2 == std::string::npos || pos2 > pos3)
-      str.insert(pos3, ":2170");
-
-    return str;
-  }
-
   EndpointQueryingStatus JobListRetrieverPluginWSRFCREAM::Query(const UserConfig& uc, const Endpoint& e, std::list<Job>& jobs, const EndpointQueryOptions<Job>&) const {
     EndpointQueryingStatus s(EndpointQueryingStatus::FAILED);
-    
-    URL url = CreateURL(e.URLString);
-    URL infourl = CreateInfoURL(url.Host());
+    URL url((e.URLString.find("://") == std::string::npos ? "https://" : "") + e.URLString, false, 8443);
+    URL infourl("ldap://" + url.Host(), false, 2170, "/o=grid");
     URL queryURL(url);
     queryURL.ChangePath(queryURL.Path() + "/CREAM2");
 
