@@ -23,47 +23,12 @@ namespace Arc {
     return pos != std::string::npos && lower(endpoint.substr(0, pos)) != "http" && lower(endpoint.substr(0, pos)) != "https";
   }
 
-  static URL CreateURL(std::string str) {
-    std::string::size_type pos1 = str.find("://");
-    if (pos1 == std::string::npos) {
-      str = "https://" + str;
-      pos1 = 5;
-    } else {
-      if(lower(str.substr(0,pos1)) != "https" && lower(str.substr(0,pos1)) != "http" ) return URL();
-    }
-    std::string::size_type pos2 = str.find(":", pos1 + 3);
-    std::string::size_type pos3 = str.find("/", pos1 + 3);
-    if (pos3 == std::string::npos && pos2 == std::string::npos) str += ":8443";
-    else if (pos2 == std::string::npos || pos2 > pos3) str.insert(pos3, ":8443");
-
-    return str;
-  }
-  
-  static URL CreateInfoURL(std::string str) {
-    std::string::size_type pos1 = str.find("://");
-    if (pos1 == std::string::npos) {
-      str = "ldap://" + str;
-      pos1 = 4;
-    } else {
-      if(lower(str.substr(0,pos1)) != "ldap") return URL();
-    }
-    std::string::size_type pos2 = str.find(":", pos1 + 3);
-    std::string::size_type pos3 = str.find("/", pos1 + 3);
-    if (pos3 == std::string::npos) {
-      if (pos2 == std::string::npos) str += ":2170";
-      str += "/o=grid";
-    }
-    else if (pos2 == std::string::npos || pos2 > pos3)
-      str.insert(pos3, ":2170");
-
-    return str;
-  }
-  
   SubmissionStatus SubmitterPluginCREAM::Submit(const std::list<JobDescription>& jobdescs, const std::string& endpoint, EntityConsumer<Job>& jc, std::list<const JobDescription*>& notSubmitted) {
     MCCConfig cfg;
     usercfg.ApplyToConfig(cfg);
-    URL url = CreateURL(endpoint);
-    URL infourl = CreateInfoURL(url.Host());
+
+    URL url((endpoint.find("://") == std::string::npos ? "https://" : "") + endpoint, false, 8443);
+    URL infourl("ldap://" + url.Host(), false, 2170, "/o=grid");
 
     SubmissionStatus retval;
     for (std::list<JobDescription>::const_iterator it = jobdescs.begin(); it != jobdescs.end(); ++it) {
@@ -82,7 +47,7 @@ namespace Arc {
       submissionurl.ChangePath(submissionurl.Path() + "/CREAM2");
       CREAMClient gLiteClientSubmission(submissionurl, cfg, usercfg.Timeout());
       gLiteClientSubmission.setDelegationId(delegationid);
-  
+
       JobDescription preparedjobdesc(*it);
       if (!preparedjobdesc.Prepare()) {
         logger.msg(INFO, "Failed to prepare job description to target resources");
@@ -98,7 +63,7 @@ namespace Arc {
         retval |= SubmissionStatus::DESCRIPTION_NOT_SUBMITTED;
         continue;
       }
-  
+
       creamJobInfo jobInfo;
       if (!gLiteClientSubmission.registerJob(jobdescstring, jobInfo)) {
         logger.msg(INFO, "Failed registering job");
@@ -107,7 +72,7 @@ namespace Arc {
         retval |= SubmissionStatus::ERROR_FROM_ENDPOINT;
         continue;
       }
-  
+
       if (!PutFiles(preparedjobdesc, jobInfo.ISB)) {
         logger.msg(INFO, "Failed uploading local input files");
         notSubmitted.push_back(&*it);
@@ -115,7 +80,7 @@ namespace Arc {
         retval |= SubmissionStatus::ERROR_FROM_ENDPOINT;
         continue;
       }
-  
+
       if (!gLiteClientSubmission.startJob(jobInfo.id)) {
         logger.msg(INFO, "Failed starting job");
         notSubmitted.push_back(&*it);
@@ -123,7 +88,7 @@ namespace Arc {
         retval |= SubmissionStatus::ERROR_FROM_ENDPOINT;
         continue;
       }
-  
+
       Job j;
       j.JobID = submissionurl.str() + '/' + jobInfo.id;
       j.ServiceInformationURL = infourl;
@@ -165,7 +130,7 @@ namespace Arc {
       submissionurl.ChangePath(submissionurl.Path() + "/CREAM2");
       CREAMClient gLiteClientSubmission(submissionurl, cfg, usercfg.Timeout());
       gLiteClientSubmission.setDelegationId(delegationid);
-  
+
       JobDescription preparedjobdesc(*it);
       if (!preparedjobdesc.Prepare(et)) {
         logger.msg(INFO, "Failed to prepare job description to target resources");
@@ -173,7 +138,7 @@ namespace Arc {
         retval |= SubmissionStatus::DESCRIPTION_NOT_SUBMITTED;
         continue;
       }
-  
+
       if (preparedjobdesc.OtherAttributes.find("egee:jdl;BatchSystem") == preparedjobdesc.OtherAttributes.end()) {
         if (!et.ComputingManager->ProductName.empty()) {
           preparedjobdesc.OtherAttributes["egee:jdl;BatchSystem"] = et.ComputingManager->ProductName;
@@ -182,7 +147,7 @@ namespace Arc {
           preparedjobdesc.OtherAttributes["egee:jdl;BatchSystem"] = et.ComputingShare->MappingQueue;
         }
       }
-  
+
       std::string jobdescstring;
       if (!preparedjobdesc.UnParse(jobdescstring, "egee:jdl")) {
         logger.msg(INFO, "Unable to submit job. Job description is not valid in the %s format", "egee:jdl");
@@ -190,7 +155,7 @@ namespace Arc {
         retval |= SubmissionStatus::DESCRIPTION_NOT_SUBMITTED;
         continue;
       }
-  
+
       creamJobInfo jobInfo;
       if (!gLiteClientSubmission.registerJob(jobdescstring, jobInfo)) {
         logger.msg(INFO, "Failed registering job");
@@ -199,7 +164,7 @@ namespace Arc {
         retval |= SubmissionStatus::ERROR_FROM_ENDPOINT;
         continue;
       }
-  
+
       if (!PutFiles(preparedjobdesc, jobInfo.ISB)) {
         logger.msg(INFO, "Failed uploading local input files");
         notSubmitted.push_back(&*it);
@@ -207,7 +172,7 @@ namespace Arc {
         retval |= SubmissionStatus::ERROR_FROM_ENDPOINT;
         continue;
       }
-  
+
       if (!gLiteClientSubmission.startJob(jobInfo.id)) {
         logger.msg(INFO, "Failed starting job");
         notSubmitted.push_back(&*it);
