@@ -6,10 +6,10 @@
 #include <list>
 #include <string>
 
-#include <arc/client/JobDescriptionParser.h>
+#include <arc/compute/JobDescriptionParserPlugin.h>
 
 /** JDLParser
- * The JDLParser class, derived from the JobDescriptionParser class, is a job
+ * The JDLParser class, derived from the JobDescriptionParserPlugin class, is a job
  * description parser for the Job Description Language (JDL) specified in CREAM
  * Job Description Language Attributes Specification for the EGEE middleware
  * (EGEE-JRA1-TEC-592336) and Job Description Language Attributes Specification
@@ -19,12 +19,12 @@
 namespace Arc {
 
   class JDLParser
-    : public JobDescriptionParser {
+    : public JobDescriptionParserPlugin {
   public:
     JDLParser(PluginArgument* parg);
     ~JDLParser();
-    JobDescriptionParserResult Parse(const std::string& source, std::list<JobDescription>& jobdescs, const std::string& language = "", const std::string& dialect = "") const;
-    JobDescriptionParserResult UnParse(const JobDescription& job, std::string& product, const std::string& language, const std::string& dialect = "") const;
+    JobDescriptionParserPluginResult Parse(const std::string& source, std::list<JobDescription>& jobdescs, const std::string& language = "", const std::string& dialect = "") const;
+    JobDescriptionParserPluginResult UnParse(const JobDescription& job, std::string& product, const std::string& language, const std::string& dialect = "") const;
 
     static Plugin* Instance(PluginArgument *arg);
 
@@ -34,14 +34,15 @@ namespace Arc {
     bool handleJDLattribute(const std::string& attributeName,
                             const std::string& attributeValue,
                             JobDescription& job) const;
-    std::string simpleJDLvalue(const std::string& attributeValue) const;
-    std::list<std::string> listJDLvalue(const std::string& attributeValue,
-                                        std::pair<char, char> bracket = std::make_pair('{', '}'),
-                                        char lineEnd = ',') const;
+    static std::string simpleJDLvalue(const std::string& attributeValue);
+    static std::list<std::string> listJDLvalue(const std::string& attributeValue,
+                                               std::pair<char, char> bracket = std::make_pair('{', '}'),
+                                               char lineEnd = ',');
     std::string generateOutputList(const std::string& attribute,
                                    const std::list<std::string>& list,
                                    std::pair<char, char> bracket = std::make_pair('{', '}'),
                                    char lineEnd = ',') const;
+    static bool ParseInputSandboxAttribute(JobDescription&);
   };
 
 } // namespace Arc
