@@ -5,6 +5,9 @@
 #include <string>
 #include <fstream>
 
+#include <list>
+std::ostream& operator<<(std::ostream& os, const std::list<std::string>& strings);
+
 #include <cppunit/extensions/HelperMacros.h>
 
 #include <arc/ArcLocation.h>
