@@ -4,12 +4,12 @@
 #include <config.h>
 #endif
 
-#include <arc/client/EndpointQueryingStatus.h>
+#include <arc/compute/EndpointQueryingStatus.h>
 #include <arc/loader/Plugin.h>
 
 #include "ServiceEndpointRetrieverPluginEMIR.h"
 
-Arc::PluginDescriptor PLUGINS_TABLE_NAME[] = {
+Arc::PluginDescriptor ARC_PLUGINS_TABLE_NAME[] = {
   { "EMIR", "HED:ServiceEndpointRetrieverPlugin", "EMIR registry", 0, &Arc::ServiceEndpointRetrieverPluginEMIR::Instance },
   { NULL, NULL, NULL, 0, NULL }
 };
