@@ -3,13 +3,15 @@
 #ifndef __ARC_SUBMITTERPLUGINUNICORE_H__
 #define __ARC_SUBMITTERPLUGINUNICORE_H__
 
-#include <arc/client/SubmitterPlugin.h>
+#include <arc/compute/SubmitterPlugin.h>
 #include <arc/XMLNode.h>
 #include <arc/loader/Loader.h>
-#include <arc/client/ClientInterface.h>
+#include <arc/communication/ClientInterface.h>
 
 namespace Arc {
 
+  class SubmissionStatus;
+  
   class SubmitterPluginUNICORE : public SubmitterPlugin {
   public:
     SubmitterPluginUNICORE(const UserConfig& usercfg, PluginArgument* parg) : SubmitterPlugin(usercfg, parg) { supportedInterfaces.push_back("org.ogf.bes"); }
@@ -22,7 +24,7 @@ namespace Arc {
 
     virtual bool isEndpointNotSupported(const std::string& endpoint) const;
 
-    virtual bool Submit(const std::list<JobDescription>& jobdesc, const ExecutionTarget& et, EntityConsumer<Job>& jc, std::list<const JobDescription*>& notSubmitted);
+    virtual SubmissionStatus Submit(const std::list<JobDescription>& jobdesc, const ExecutionTarget& et, EntityConsumer<Job>& jc, std::list<const JobDescription*>& notSubmitted);
   private:
     static Logger logger;
   };
