@@ -79,9 +79,9 @@ namespace ArcDMCGFAL {
     : DataPointDirect(u, usercfg, parg), fd(-1), reading(false), writing(false) {
       LogLevel loglevel = logger.getThreshold();
       if (loglevel == DEBUG)
-        gfal_set_verbose (GFAL_VERBOSE_VERBOSE | GFAL_VERBOSE_DEBUG | GFAL_VERBOSE_TRACE);
+        gfal2_log_set_level (G_LOG_LEVEL_DEBUG);
       if (loglevel == VERBOSE)
-        gfal_set_verbose (GFAL_VERBOSE_VERBOSE);
+        gfal2_log_set_level (G_LOG_LEVEL_INFO);
       if (url.Protocol() == "lfc")
         lfc_host = url.Host();
   }
@@ -185,8 +185,11 @@ namespace ArcDMCGFAL {
       }
 
       // Read into the buffer
-      bytes_read = gfal_read(fd, (*(buffer))[handle], length);
-            
+      {
+        GFALEnvLocker gfal_lock(usercfg, lfc_host);
+        bytes_read = gfal_read(fd, (*(buffer))[handle], length);
+      }
+
       // If there was an error
       if (bytes_read < 0) {
         logger.msg(VERBOSE, "gfal_read failed: %s", StrError(errno));
@@ -211,7 +214,12 @@ namespace ArcDMCGFAL {
     buffer->eof_read(true);
     // Close the file
     if (fd != -1) {
-      if (gfal_close(fd) < 0) {
+      int r;
+      {
+        GFALEnvLocker gfal_lock(usercfg, lfc_host);
+        r = gfal_close(fd);
+      }
+      if (r < 0) {
         logger.msg(WARNING, "gfal_close failed: %s", StrError(gfal_posix_code_error()));
       }
       fd = -1;
@@ -232,7 +240,12 @@ namespace ArcDMCGFAL {
 
     // Close the file if not already done
     if (fd != -1) {
-      if (gfal_close(fd) < 0) {
+      int r;
+      {
+        GFALEnvLocker gfal_lock(usercfg, lfc_host);
+        r = gfal_close(fd);
+      }
+      if (r < 0) {
         logger.msg(WARNING, "gfal_close failed: %s", StrError(gfal_posix_code_error()));
       }
       fd = -1;
@@ -344,7 +357,10 @@ namespace ArcDMCGFAL {
       // destination, then we have to seek there
       if (position != offset) {
         logger.msg(DEBUG, "DataPointGFAL::write_file got position %d and offset %d, has to seek", position, offset);
-        gfal_lseek(fd, position, SEEK_SET);
+        {
+          GFALEnvLocker gfal_lock(usercfg, lfc_host);
+          gfal_lseek(fd, position, SEEK_SET);
+        }
         offset = position;
       }
       
@@ -352,7 +368,10 @@ namespace ArcDMCGFAL {
       // but we may not be able to write it in one shot
       chunk_offset = 0;
       while (chunk_offset < length) {
-        bytes_written = gfal_write(fd, (*(buffer))[handle] + chunk_offset, length - chunk_offset);
+        {
+          GFALEnvLocker gfal_lock(usercfg, lfc_host);
+          bytes_written = gfal_write(fd, (*(buffer))[handle] + chunk_offset, length - chunk_offset);
+        }
         if (bytes_written < 0) break; // there was an error
         // calculate how far we got into to the chunk
         chunk_offset += bytes_written;
@@ -375,7 +394,12 @@ namespace ArcDMCGFAL {
     buffer->eof_write(true);
     // Close the file
     if (fd != -1) {
-      if (gfal_close(fd) < 0) {
+      int r;
+      {
+        GFALEnvLocker gfal_lock(usercfg, lfc_host);
+        r = gfal_close(fd);
+      }
+      if (r < 0) {
         logger.msg(WARNING, "gfal_close failed: %s", StrError(gfal_posix_code_error()));
       }
       fd = -1;
@@ -397,7 +421,12 @@ namespace ArcDMCGFAL {
 
     // Close the file if not done already
     if (fd != -1) {
-      if (gfal_close(fd) < 0) {
+      int r;
+      {
+        GFALEnvLocker gfal_lock(usercfg, lfc_host);
+        r = gfal_close(fd);
+      }
+      if (r < 0) {
         logger.msg(WARNING, "gfal_close failed: %s", StrError(gfal_posix_code_error()));
       }
       fd = -1;
@@ -411,7 +440,7 @@ namespace ArcDMCGFAL {
     return DataStatus::Success;
   }  
   
-  DataStatus DataPointGFAL::do_stat(const URL& stat_url, FileInfo& file) {
+  DataStatus DataPointGFAL::do_stat(const URL& stat_url, FileInfo& file, DataPointInfoType verb) {
     struct stat st;
     int res;
     {
@@ -456,6 +485,23 @@ namespace ArcDMCGFAL {
     if (st.st_mode & S_IXOTH) perms += 'x'; else perms += '-';
     file.SetMetaData("accessperm", perms);
 
+    if (verb & INFO_TYPE_STRUCT) {
+      char replicas[65536];
+      ssize_t r;
+      {
+        GFALEnvLocker gfal_lock(usercfg, lfc_host);
+        r = gfal_getxattr(GFALUtils::GFALURL(stat_url).c_str(), "user.replicas", replicas, sizeof(replicas));
+      }
+      if (r < 0) {
+        logger.msg(VERBOSE, "gfal_listxattr failed, no replica information can be obtained: %s", StrError(gfal_posix_code_error()));
+      } else {
+        std::vector<std::string> reps;
+        tokenize(replicas, reps, "\n");
+        for (std::vector<std::string>::const_iterator u = reps.begin(); u != reps.end(); ++u) {
+          file.AddURL(URL(*u));
+        }
+      }
+    }
     return DataStatus::Success;    
   }
 
@@ -464,7 +510,7 @@ namespace ArcDMCGFAL {
     if (writing) return DataStatus(DataStatus::IsWritingError, EARCLOGIC);
     
     FileInfo file;
-    DataStatus status_from_stat = do_stat(url, file);
+    DataStatus status_from_stat = do_stat(url, file, (DataPointInfoType)(INFO_TYPE_ACCESS | INFO_TYPE_CONTENT));
     
     if (!status_from_stat) {
       return DataStatus(DataStatus::CheckError, status_from_stat.GetErrno());
@@ -476,7 +522,7 @@ namespace ArcDMCGFAL {
   }
   
   DataStatus DataPointGFAL::Stat(FileInfo& file, DataPointInfoType verb) {
-    return do_stat(url, file);
+    return do_stat(url, file, verb);
   }
 
   DataStatus DataPointGFAL::List(std::list<FileInfo>& files, DataPointInfoType verb) {
@@ -501,7 +547,7 @@ namespace ArcDMCGFAL {
       if (verb & (INFO_TYPE_TIMES | INFO_TYPE_ACCESS | INFO_TYPE_TYPE)) {
         URL child_url = URL(url.plainstr() + '/' + d->d_name);
         logger.msg(DEBUG, "List will stat the URL %s", child_url.plainstr());
-        do_stat(child_url, *f);
+        do_stat(child_url, *f, verb);
       }
     }
     
@@ -519,7 +565,7 @@ namespace ArcDMCGFAL {
     if (reading) return DataStatus(DataStatus::IsReadingError, EARCLOGIC);
     if (writing) return DataStatus(DataStatus::IsWritingError, EARCLOGIC);
     FileInfo file;
-    DataStatus status_from_stat = do_stat(url, file);
+    DataStatus status_from_stat = do_stat(url, file, (DataPointInfoType)(INFO_TYPE_TYPE));
     if (!status_from_stat)
       return DataStatus(DataStatus::DeleteError, status_from_stat.GetErrno());
 
