@@ -1138,6 +1138,12 @@ namespace ArcDMCGridFTP {
                    "globus_ftp_client_operationattr_set_allow_ipv6 failed");
         logger.msg(WARNING, "Globus error: %s", res.str());
       }
+      if (!(res = globus_ftp_client_operationattr_set_delayed_pasv(&ftp_opattr,
+                                                                   GLOBUS_TRUE))) {
+        logger.msg(WARNING, "init_handle: "
+                   "globus_ftp_client_operationattr_set_delayed_pasv failed");
+        logger.msg(WARNING, "Globus error: %s", res.str());
+      }
     }
     ftp_active = true;
     ftp_threads = 1;
