@@ -11,11 +11,13 @@
 
 #include <arc/Thread.h>
 #include <arc/data/DataPointDirect.h>
+#include <arc/URL.h>
+#include <arc/globusutils/GSSCredential.h>
 
-namespace Arc {
+namespace ArcDMCGridFTP {
+
+  using namespace Arc;
 
-  class GSSCredential;
-  class URL;
   class Lister;
 
   /**
@@ -33,8 +35,8 @@ namespace Arc {
     private:
       Glib::Mutex lock;
       DataPointGridFTP* arg;
-      CBArg(void) {};
-      CBArg(const CBArg&) {};
+      CBArg(void);
+      CBArg(const CBArg&);
     public:
       CBArg(DataPointGridFTP* a);
       ~CBArg(void) {};
@@ -111,16 +113,18 @@ namespace Arc {
                                     DataCallback *space_cb = NULL);
     virtual DataStatus StopReading();
     virtual DataStatus StopWriting();
-    virtual DataStatus Check();
+    virtual DataStatus Check(bool check_meta);
     virtual DataStatus Remove();
     virtual DataStatus CreateDirectory(bool with_parents=false);
     virtual DataStatus Stat(FileInfo& file, DataPointInfoType verb = INFO_TYPE_ALL);
     virtual DataStatus List(std::list<FileInfo>& files, DataPointInfoType verb = INFO_TYPE_ALL);
+    virtual DataStatus Rename(const URL& newurl);
     virtual bool WriteOutOfOrder();
     virtual bool ProvidesMeta() const;
     virtual const std::string DefaultCheckSum() const;
+    virtual bool RequiresCredentials() const;
   };
 
-} // namespace Arc
+} // namespace ArcDMCGridFTP
 
 #endif // __ARC_DATAPOINTGRIDFTP_H__
