@@ -13,21 +13,21 @@
 
 #include <unistd.h>
 
-namespace Arc {
+namespace ArcDMCSRM {
+
+  using namespace Arc;
 
   SRM1Client::SRM1Client(const UserConfig& usercfg, const SRMURL& url)
     : SRMClient(usercfg, url) {
     version = "v1";
-    ns["SRMv1Type"] =
-      "http://www.themindelectric.com/package/diskCacheV111.srm/";
-    ns["SRMv1Meth"] =
-      "http://tempuri.org/diskCacheV111.srm.server.SRMServerV1";
+    ns["SRMv1Type"] = "http://www.themindelectric.com/package/diskCacheV111.srm/";
+    ns["SRMv1Meth"] = "http://tempuri.org/diskCacheV111.srm.server.SRMServerV1";
   }
 
   SRM1Client::~SRM1Client() {}
 
-  SRMReturnCode SRM1Client::getTURLs(SRMClientRequest& creq,
-                                     std::list<std::string>& urls) {
+  DataStatus SRM1Client::getTURLs(SRMClientRequest& creq,
+                                  std::list<std::string>& urls) {
     SRMURL srmurl(creq.surls().front());
     std::list<int> file_ids;
 
@@ -47,15 +47,14 @@ namespace Arc {
     arg1node.NewChild("item") = "ftp";
 
     PayloadSOAP *response = NULL;
-    SRMReturnCode status = process("get", &request, &response);
-    if (status != SRM_OK)
-      return status;
+    DataStatus status = process("get", &request, &response);
+    if (!status) return DataStatus(DataStatus::ReadPrepareError, status.GetErrno(), status.GetDesc());
 
     XMLNode result = (*response)["getResponse"]["Result"];
     if (!result) {
-      logger.msg(INFO, "SRM did not return any information");
+      logger.msg(VERBOSE, "SRM did not return any information");
       delete response;
-      return SRM_ERROR_OTHER;
+      return DataStatus(DataStatus::ReadPrepareError, EARCRESINVAL, "SRM did not return any information");
     }
 
     std::string request_state = (std::string)result["state"];
@@ -63,26 +62,22 @@ namespace Arc {
     time_t t_start = time(NULL);
 
     for (;;) {
-      for (XMLNode n = result["fileStatuses"]["item"]; n; ++n)
-        if (strcasecmp(((std::string)n["state"]).c_str(), "ready") == 0)
+      for (XMLNode n = result["fileStatuses"]["item"]; n; ++n) {
+        if (strcasecmp(((std::string)n["state"]).c_str(), "ready") == 0) {
           if (n["TURL"]) {
             urls.push_back(n["TURL"]);
             file_ids.push_back(stringtoi(n["fileId"]));
           }
-      if (!urls.empty())         // Have requested data
-        break;
-      if (request_state.empty()) // No data and no state - fishy
-        break;
-      if (strcasecmp(request_state.c_str(), "pending") != 0)
-        break;
-      if ((time(NULL) - t_start) > creq.request_timeout())
-        break;
+        }
+      }
+      if (!urls.empty()) break; // Have requested data
+      if (request_state.empty()) break; // No data and no state - fishy
+      if (strcasecmp(request_state.c_str(), "pending") != 0) break;
+      if ((time(NULL) - t_start) > creq.request_timeout()) break;
 
       int retryDeltaTime = stringtoi(result["retryDeltaTime"]);
-      if (retryDeltaTime < 1)
-        retryDeltaTime = 1;
-      if (retryDeltaTime > 10)
-        retryDeltaTime = 10;
+      if (retryDeltaTime < 1) retryDeltaTime = 1;
+      if (retryDeltaTime > 10) retryDeltaTime = 10;
       sleep(retryDeltaTime);
 
       PayloadSOAP request(ns);
@@ -92,14 +87,13 @@ namespace Arc {
       delete response;
       response = NULL;
       status = process("getRequestStatus", &request, &response);
-      if (status != SRM_OK)
-        return status;
+      if (!status) return DataStatus(DataStatus::ReadPrepareError, status.GetErrno(), status.GetDesc());
 
       result = (*response)["getRequestStatusResponse"]["Result"];
       if (!result) {
-        logger.msg(INFO, "SRM did not return any information");
+        logger.msg(VERBOSE, "SRM did not return any information");
         delete response;
-        return SRM_ERROR_OTHER;
+        return DataStatus(DataStatus::ReadPrepareError, EARCRESINVAL, "SRM did not return any information");
       }
 
       request_state = (std::string)result["state"];
@@ -107,13 +101,12 @@ namespace Arc {
 
     creq.file_ids(file_ids);
     delete response;
-    if (urls.empty())
-      return SRM_ERROR_OTHER;
-    return acquire(creq, urls);
+    if (urls.empty()) return DataStatus(DataStatus::ReadPrepareError, EARCRESINVAL, "SRM did not return any TURLs");
+    return acquire(creq, urls, true);
   }
 
-  SRMReturnCode SRM1Client::putTURLs(SRMClientRequest& creq,
-                                     std::list<std::string>& urls) {
+  DataStatus SRM1Client::putTURLs(SRMClientRequest& creq,
+                                  std::list<std::string>& urls) {
     SRMURL srmurl(creq.surls().front());
     std::list<int> file_ids;
 
@@ -145,15 +138,14 @@ namespace Arc {
     arg4node.NewChild("item") = "ftp";
 
     PayloadSOAP *response = NULL;
-    SRMReturnCode status = process("put", &request, &response);
-    if (status != SRM_OK)
-      return status;
+    DataStatus status = process("put", &request, &response);
+    if (!status) return DataStatus(DataStatus::WritePrepareError, status.GetErrno(), status.GetDesc());
 
     XMLNode result = (*response)["putResponse"]["Result"];
     if (!result) {
-      logger.msg(INFO, "SRM did not return any information");
+      logger.msg(VERBOSE, "SRM did not return any information");
       delete response;
-      return SRM_ERROR_OTHER;
+      return DataStatus(DataStatus::WritePrepareError, EARCRESINVAL, "SRM did not return any information");
     }
 
     std::string request_state = (std::string)result["state"];
@@ -161,26 +153,22 @@ namespace Arc {
     time_t t_start = time(NULL);
 
     for (;;) {
-      for (XMLNode n = result["fileStatuses"]["item"]; n; ++n)
-        if (strcasecmp(((std::string)n["state"]).c_str(), "ready") == 0)
+      for (XMLNode n = result["fileStatuses"]["item"]; n; ++n) {
+        if (strcasecmp(((std::string)n["state"]).c_str(), "ready") == 0) {
           if (n["TURL"]) {
             urls.push_back(n["TURL"]);
             file_ids.push_back(stringtoi(n["fileId"]));
           }
-      if (!urls.empty())         // Have requested data
-        break;
-      if (request_state.empty()) // No data and no state - fishy
-        break;
-      if (strcasecmp(request_state.c_str(), "pending") != 0)
-        break;
-      if ((time(NULL) - t_start) > creq.request_timeout())
-        break;
+        }
+      }
+      if (!urls.empty()) break; // Have requested data
+      if (request_state.empty()) break; // No data and no state - fishy
+      if (strcasecmp(request_state.c_str(), "pending") != 0) break;
+      if ((time(NULL) - t_start) > creq.request_timeout()) break;
 
       int retryDeltaTime = stringtoi(result["retryDeltaTime"]);
-      if (retryDeltaTime < 1)
-        retryDeltaTime = 1;
-      if (retryDeltaTime > 10)
-        retryDeltaTime = 10;
+      if (retryDeltaTime < 1) retryDeltaTime = 1;
+      if (retryDeltaTime > 10) retryDeltaTime = 10;
       sleep(retryDeltaTime);
 
       PayloadSOAP request(ns);
@@ -190,14 +178,13 @@ namespace Arc {
       delete response;
       response = NULL;
       status = process("getRequestStatus", &request, &response);
-      if (status != SRM_OK)
-        return status;
+      if (!status) return DataStatus(DataStatus::WritePrepareError, status.GetErrno(), status.GetDesc());
 
       result = (*response)["getRequestStatusResponse"]["Result"];
       if (!result) {
-        logger.msg(INFO, "SRM did not return any information");
+        logger.msg(VERBOSE, "SRM did not return any information");
         delete response;
-        return SRM_ERROR_OTHER;
+        return DataStatus(DataStatus::WritePrepareError, EARCRESINVAL, "SRM did not return any information");
       }
 
       request_state = (std::string)result["state"];
@@ -205,13 +192,12 @@ namespace Arc {
 
     creq.file_ids(file_ids);
     delete response;
-    if (urls.empty())
-      return SRM_ERROR_OTHER;
-    return acquire(creq, urls);
+    if (urls.empty()) return DataStatus(DataStatus::ReadPrepareError, EARCRESINVAL, "SRM did not return any TURLs");
+    return acquire(creq, urls, false);
   }
 
-  SRMReturnCode SRM1Client::copy(SRMClientRequest& creq,
-                                 const std::string& source) {
+  DataStatus SRM1Client::copy(SRMClientRequest& creq,
+                              const std::string& source) {
     SRMURL srmurl(creq.surls().front());
     std::list<int> file_ids;
 
@@ -231,15 +217,14 @@ namespace Arc {
     arg2node.NewChild("item") = "false";
 
     PayloadSOAP *response = NULL;
-    SRMReturnCode status = process("copy", &request, &response);
-    if (status != SRM_OK)
-      return status;
+    DataStatus status = process("copy", &request, &response);
+    if (status != 0) return status;
 
     XMLNode result = (*response)["copyResponse"]["Result"];
     if (!result) {
-      logger.msg(INFO, "SRM did not return any information");
+      logger.msg(VERBOSE, "SRM did not return any information");
       delete response;
-      return SRM_ERROR_OTHER;
+      return DataStatus(DataStatus::TransferError, EARCRESINVAL, "SRM did not return any information");
     }
 
     std::string request_state = (std::string)result["state"];
@@ -247,24 +232,21 @@ namespace Arc {
     time_t t_start = time(NULL);
 
     for (;;) {
-      for (XMLNode n = result["fileStatuses"]["item"]; n; ++n)
-        if (strcasecmp(((std::string)n["state"]).c_str(), "ready") == 0)
+      for (XMLNode n = result["fileStatuses"]["item"]; n; ++n) {
+        if (strcasecmp(((std::string)n["state"]).c_str(), "ready") == 0) {
           file_ids.push_back(stringtoi(n["fileId"]));
-      if (!file_ids.empty())     // Have requested data
-        break;
-      if (request_state.empty()) // No data and no state - fishy
-        break;
+        }
+      }
+      if (!file_ids.empty()) break; // Have requested data
+
+      if (request_state.empty()) break; // No data and no state - fishy
       if ((strcasecmp(request_state.c_str(), "pending") != 0) &&
-          (strcasecmp(request_state.c_str(), "active") != 0))
-        break;
-      if ((time(NULL) - t_start) > creq.request_timeout())
-        break;
+          (strcasecmp(request_state.c_str(), "active") != 0)) break;
+      if ((time(NULL) - t_start) > creq.request_timeout()) break;
 
       int retryDeltaTime = stringtoi(result["retryDeltaTime"]);
-      if (retryDeltaTime < 1)
-        retryDeltaTime = 1;
-      if (retryDeltaTime > 10)
-        retryDeltaTime = 10;
+      if (retryDeltaTime < 1) retryDeltaTime = 1;
+      if (retryDeltaTime > 10) retryDeltaTime = 10;
       sleep(retryDeltaTime);
 
       PayloadSOAP request(ns);
@@ -274,28 +256,27 @@ namespace Arc {
       delete response;
       response = NULL;
       status = process("getRequestStatus", &request, &response);
-      if (status != SRM_OK)
-        return status;
+      if (status != 0) return status;
 
       result = (*response)["getRequestStatusResponse"]["Result"];
       if (!result) {
-        logger.msg(INFO, "SRM did not return any information");
+        logger.msg(VERBOSE, "SRM did not return any information");
         delete response;
-        return SRM_ERROR_OTHER;
+        return DataStatus(DataStatus::TransferError, EARCRESINVAL, "SRM did not return any information");
       }
 
       request_state = (std::string)result["state"];
     }
 
     delete response;
-    if (file_ids.empty())
-      return SRM_ERROR_OTHER;
+    if (file_ids.empty()) return DataStatus(DataStatus::TransferError, EARCRESINVAL, "SRM did not return any file IDs");
     creq.file_ids(file_ids);
-    return release(creq);
+    return release(creq, true);
   }
 
-  SRMReturnCode SRM1Client::acquire(SRMClientRequest& creq,
-                                    std::list<std::string>& urls) {
+  DataStatus SRM1Client::acquire(SRMClientRequest& creq,
+                                 std::list<std::string>& urls,
+                                 bool source) {
     std::list<int> file_ids = creq.file_ids();
 
     // Tell server to move files into "Running" state
@@ -318,20 +299,19 @@ namespace Arc {
       arg2node.NewChild("item") = "Running";
 
       PayloadSOAP *response = NULL;
-      SRMReturnCode status = process("setFileStatus", &request, &response);
-      if (status != SRM_OK)
-        return status;
+      DataStatus status = process("setFileStatus", &request, &response);
+      if (status != 0) return status;
 
       XMLNode result = (*response)["setFileStatusResponse"]["Result"];
       if (!result) {
-        logger.msg(INFO, "SRM did not return any information");
+        logger.msg(VERBOSE, "SRM did not return any information");
         delete response;
-        return SRM_ERROR_OTHER;
+        return DataStatus(source ? DataStatus::ReadPrepareError : DataStatus::WritePrepareError,
+                          EARCRESINVAL, "SRM did not return any information");
       }
 
       for (XMLNode n = result["fileStatuses"]["item"]; n; ++n) {
-        if (stringtoi(n["fileId"]) != *file_id)
-          continue;
+        if (stringtoi(n["fileId"]) != *file_id) continue;
         if (strcasecmp(((std::string)n["state"]).c_str(), "running") == 0) {
           ++file_id;
           ++file_url;
@@ -348,12 +328,12 @@ namespace Arc {
     }
 
     creq.file_ids(file_ids);
-    if (urls.empty())
-      return SRM_ERROR_OTHER;
-    return SRM_OK;
+    if (urls.empty()) return DataStatus(source ? DataStatus::ReadPrepareError : DataStatus::WritePrepareError,
+                                        EARCRESINVAL, "SRM did not return any information");
+    return DataStatus::Success;
   }
 
-  SRMReturnCode SRM1Client::remove(SRMClientRequest& creq) {
+  DataStatus SRM1Client::remove(SRMClientRequest& creq) {
     SRMURL srmurl(creq.surls().front());
 
     PayloadSOAP request(ns);
@@ -364,16 +344,13 @@ namespace Arc {
     arg0node.NewChild("item") = srmurl.FullURL();
 
     PayloadSOAP *response = NULL;
-    SRMReturnCode status = process("advisoryDelete", &request, &response);
-    if (status != SRM_OK)
-      return status;
-
+    DataStatus status = process("advisoryDelete", &request, &response);
     delete response;
-    return SRM_OK;
+    return status;
   }
 
-  SRMReturnCode SRM1Client::info(SRMClientRequest& creq,
-                                 std::map<std::string, std::list<struct SRMFileMetaData> >& metadata) {
+  DataStatus SRM1Client::info(SRMClientRequest& creq,
+                              std::map<std::string, std::list<struct SRMFileMetaData> >& metadata) {
     SRMURL srmurl(creq.surls().front());
 
     PayloadSOAP request(ns);
@@ -384,24 +361,21 @@ namespace Arc {
     arg0node.NewChild("item") = srmurl.FullURL();
 
     PayloadSOAP *response = NULL;
-    SRMReturnCode status = process("getFileMetaData", &request, &response);
-    if (status != SRM_OK)
-      return status;
+    DataStatus status = process("getFileMetaData", &request, &response);
+    if (status != 0) return status;
 
     XMLNode result = (*response)["getFileMetaDataResponse"]["Result"];
     if (!result) {
-      logger.msg(creq.error_loglevel(),
-                 "SRM did not return any information");
+      logger.msg(VERBOSE, "SRM did not return any information");
       delete response;
-      return SRM_ERROR_OTHER;
+      return DataStatus(DataStatus::StatError, EARCRESINVAL, "SRM did not return any information");
     }
 
     XMLNode mdata = result["item"];
     if (!mdata) {
-      logger.msg(creq.error_loglevel(),
-                 "SRM did not return any useful information");
+      logger.msg(VERBOSE, "SRM did not return any useful information");
       delete response;
-      return SRM_ERROR_OTHER;
+      return DataStatus(DataStatus::StatError, EARCRESINVAL, "SRM did not return any useful information");
     }
 
     struct SRMFileMetaData md;
@@ -412,35 +386,33 @@ namespace Arc {
       md.path.erase(i, 1);
       i = md.path.find("//", i);
     }
-    if (md.path.find("/") != 0)
-      md.path = "/" + md.path;
+    if (md.path.find("/") != 0) md.path = "/" + md.path;
     // date, type and locality not supported in v1
     md.createdAtTime = (time_t)0;
     md.fileType = SRM_FILE_TYPE_UNKNOWN;
     md.fileLocality = SRM_UNKNOWN;
     md.size = stringtoull(mdata["size"]);
-    if (mdata["checksumType"])
-      md.checkSumType = (std::string)mdata["checksumType"];
-    if (mdata["checksumValue"])
-      md.checkSumValue = (std::string)mdata["checksumValue"];
+    if (mdata["checksumType"]) md.checkSumType = (std::string)mdata["checksumType"];
+    if (mdata["checksumValue"]) md.checkSumValue = (std::string)mdata["checksumValue"];
     std::list<struct SRMFileMetaData> mdlist;
     mdlist.push_back(md);
     metadata[creq.surls().front()] = mdlist;
 
     delete response;
-    return SRM_OK;
+    return DataStatus::Success;
   }
 
-  SRMReturnCode SRM1Client::info(SRMClientRequest& req,
+  DataStatus SRM1Client::info(SRMClientRequest& req,
                                  std::list<struct SRMFileMetaData>& metadata) {
     std::map<std::string, std::list<struct SRMFileMetaData> > metadata_map;
-    SRMReturnCode res = info(req, metadata_map);
-    if (res != SRM_OK || metadata_map.find(req.surls().front()) == metadata_map.end()) return res;
+    DataStatus res = info(req, metadata_map);
+    if (!res || metadata_map.find(req.surls().front()) == metadata_map.end()) return res;
     metadata = metadata_map[req.surls().front()];
-    return SRM_OK;
+    return DataStatus::Success;
   }
 
-  SRMReturnCode SRM1Client::release(SRMClientRequest& creq) {
+  DataStatus SRM1Client::release(SRMClientRequest& creq,
+                                 bool source) {
     std::list<int> file_ids = creq.file_ids();
 
     // Tell server to move files into "Done" state
@@ -462,22 +434,22 @@ namespace Arc {
       arg2node.NewChild("item") = "Done";
 
       PayloadSOAP *response = NULL;
-      SRMReturnCode status = process("setFileStatus", &request, &response);
-      if (status != SRM_OK)
-        return status;
+      DataStatus status = process("setFileStatus", &request, &response);
+      if (status != 0) return status;
 
       XMLNode result = (*response)["setFileStatusResponse"]["Result"];
       if (!result) {
-        logger.msg(INFO, "SRM did not return any information");
+        logger.msg(VERBOSE, "SRM did not return any information");
         delete response;
-        return SRM_ERROR_OTHER;
+        return DataStatus(source ? DataStatus::ReadFinishError : DataStatus::WriteFinishError,
+                          EARCRESINVAL, "SRM did not return any information");
       }
 
       for (XMLNode n = result["fileStatuses"]["item"]; n; ++n) {
-        if (stringtoi(n["fileId"]) != *file_id)
-          continue;
-        if (strcasecmp(((std::string)n["state"]).c_str(), "done") == 0)
+        if (stringtoi(n["fileId"]) != *file_id) continue;
+        if (strcasecmp(((std::string)n["state"]).c_str(), "done") == 0) {
           ++file_id;
+        }
         else {
           logger.msg(VERBOSE, "File could not be moved to Done state");
           file_id = file_ids.erase(file_id);
@@ -488,19 +460,20 @@ namespace Arc {
     }
 
     creq.file_ids(file_ids);
-    return SRM_OK;
+    return DataStatus::Success;
   }
 
-  SRMReturnCode SRM1Client::releaseGet(SRMClientRequest& creq) {
-    return release(creq);
+  DataStatus SRM1Client::releaseGet(SRMClientRequest& creq) {
+    return release(creq, true);
   }
 
-  SRMReturnCode SRM1Client::releasePut(SRMClientRequest& creq) {
-    return release(creq);
+  DataStatus SRM1Client::releasePut(SRMClientRequest& creq) {
+    return release(creq, false);
   }
 
-  SRMReturnCode SRM1Client::abort(SRMClientRequest& creq) {
-    return release(creq);
+  DataStatus SRM1Client::abort(SRMClientRequest& creq,
+                               bool source) {
+    return release(creq, source);
   }
 
-} // namespace Arc
+} // namespace ArcDMCSRM
