@@ -228,6 +228,7 @@ namespace Arc {
 #endif
 
   void ThreadArgument::thread(void) {
+    ThreadId::getInstance().add();
 #ifdef USE_THREAD_DATA
     ThreadData* tdata = ThreadData::Get();
     if(tdata) {
@@ -248,6 +249,32 @@ namespace Arc {
 #ifdef USE_THREAD_DATA
     ThreadData::Remove();
 #endif
+    ThreadId::getInstance().remove();
+  }
+
+  ThreadId& ThreadId::getInstance() {
+    static ThreadId* id = new ThreadId();
+    return *id;
+  }
+
+  ThreadId::ThreadId(): thread_no(0) {}
+
+  void ThreadId::add() {
+    Glib::Mutex::Lock lock(mutex);
+    if (thread_no == ULONG_MAX) thread_no = 0;
+    thread_ids[(size_t)(void*)Glib::Thread::self()] = ++thread_no;
+  }
+
+  void ThreadId::remove() {
+    Glib::Mutex::Lock lock(mutex);
+    thread_ids.erase((size_t)(void*)Glib::Thread::self());
+  }
+
+  unsigned long int ThreadId::get() {
+    Glib::Mutex::Lock lock(mutex);
+    size_t id = (size_t)(void*)Glib::Thread::self();
+    if (thread_ids.count(id) == 0) return id;
+    return thread_ids[id];
   }
 
   bool CreateThreadFunction(void (*func)(void*), void *arg, SimpleCounter* count
