@@ -42,50 +42,57 @@ static Glib::Mutex suid_lock;
     return getgid();
   }
 
-  void User::set(const struct passwd *pwd_p) {
+  bool User::set(const struct passwd *pwd_p) {
     if (pwd_p == NULL)
-      return;
-    home = GetEnv("HOME");
+      return false;
     name = pwd_p->pw_name;
-    if (home.empty())
-      home = pwd_p->pw_dir;
     uid = pwd_p->pw_uid;
     gid = pwd_p->pw_gid;
+    home = GetEnv("HOME");
+    // don't use HOME if user is different from current user
+    if (home.empty() || uid != get_user_id()) home = pwd_p->pw_dir;
+    return true;
   }
 
-  User::User(void) {
+  User::User(void): valid(false) {
     uid = get_user_id();
     gid = get_group_id();
     struct passwd pwd;
     char pwdbuf[2048];
     struct passwd *pwd_p;
-    getpwuid_r(uid, &pwd, pwdbuf, sizeof(pwdbuf), &pwd_p);
-    set(pwd_p);
+    if (getpwuid_r(uid, &pwd, pwdbuf, sizeof(pwdbuf), &pwd_p) != 0) return;
+    if (!set(pwd_p)) return;
+    valid = true;
   }
 
   // Unix implementation
-  User::User(const std::string& name) {
+  User::User(const std::string& name, const std::string& group): valid(false) {
     this->name = name;
     struct passwd pwd;
     char pwdbuf[2048];
     struct passwd *pwd_p;
-    getpwnam_r(name.c_str(), &pwd, pwdbuf, sizeof(pwdbuf), &pwd_p);
-    set(pwd_p);
+    if (getpwnam_r(name.c_str(), &pwd, pwdbuf, sizeof(pwdbuf), &pwd_p) != 0) return;
+    if (!set(pwd_p)) return;
+    if (!group.empty()) {
+      // override gid with given group
+      struct group* gr = getgrnam(group.c_str());
+      if (!gr) return;
+      gid = gr->gr_gid;
+    }
+    valid = true;
   }
 
-  User::User(int uid) {
+  User::User(int uid, int gid): valid(false) {
     this->uid = uid;
-    this->gid = -1;
+    this->gid = gid;
     struct passwd pwd;
     char pwdbuf[2048];
     struct passwd *pwd_p;
-    getpwuid_r(uid, &pwd, pwdbuf, sizeof(pwdbuf), &pwd_p);
-    set(pwd_p);
-  }
-
-  bool User::RunAs(std::string) {
-    // XXX NOP
-    return false;
+    if (getpwuid_r(uid, &pwd, pwdbuf, sizeof(pwdbuf), &pwd_p) != 0) return;
+    if (!set(pwd_p)) return;
+    // override what is found in passwd with given gid
+    if (gid != -1) this->gid = gid;
+    valid = true;
   }
 
   int User::check_file_access(const std::string& path, int flags) const {
@@ -151,6 +158,16 @@ static Glib::Mutex suid_lock;
     return 0;
   }
 
+  bool User::SwitchUser() const {
+    // set proper umask
+    umask(0077);
+    if (getuid() != 0 && uid != 0 && getuid() != uid) return false;
+    if (uid != 0) {
+      setgid(gid); // this is not an error if group failed, not a big deal
+      if (setuid(uid) != 0) return false;
+    }
+    return true;
+  }
 
 #else
   // Win32 implementation
@@ -163,16 +180,17 @@ static Glib::Mutex suid_lock;
     return 0; // TODO: The user id is not used on windows for file permissions etc.
   }
 
-  void User::set(const struct passwd *pwd_p) {
+  bool User::set(const struct passwd *pwd_p) {
     if (pwd_p == NULL)
-      return;
+      return false;
     name = pwd_p->pw_name;
     home = pwd_p->pw_dir;
     uid = pwd_p->pw_uid;
     gid = pwd_p->pw_gid;
+    return true;
   }
 
-  User::User(void) {
+  User::User(void): valid(false) {
     int uid = get_user_id();
     int gid = get_group_id();
     bool found;
@@ -190,12 +208,14 @@ static Glib::Mutex suid_lock;
     pwd_p.pw_dir = const_cast<char*>(home.c_str());
 
     set(&pwd_p);
+    valid = true;
   }
 
-  User::User(const std::string& name) {
+  User::User(const std::string& name, const std::string& group): valid(false) {
     this->name = name;
     int uid = get_user_id();
     int gid = get_group_id();
+    // TODO: get gid from group
 
     struct passwd pwd_p;
 
@@ -207,11 +227,13 @@ static Glib::Mutex suid_lock;
     pwd_p.pw_dir = const_cast<char*>(home.c_str());
 
     set(&pwd_p);
+    valid = true;
   }
 
-  User::User(int uid) {
+  User::User(int uid, int gid): valid(false) {
     this->uid = uid;
-    this->gid = 0;
+    this->gid = gid;
+    if (this->gid == -1) this->gid = 0;
 
     bool found;
 
@@ -228,16 +250,18 @@ static Glib::Mutex suid_lock;
     pwd_p.pw_dir = const_cast<char*>(home.c_str());
 
     set(&pwd_p);
-  }
-  bool User::RunAs(std::string cmd) {
-    // XXX NOP
-    return false;
+    valid = true;
   }
 
   int User::check_file_access(const std::string& path, int flags) const {
     // XXX NOP
     return 0;
   }
+
+  bool User::SwitchUser() const {
+    // XXX NOP
+    return false;
+  }
 #endif
 
 #ifndef WIN32
