@@ -1,6 +1,11 @@
 // -*- indent-tabs-mode: nil -*-
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 
 #include <string>
+#include <unistd.h>
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -78,7 +83,7 @@ void ThreadTest::TestThread() {
   }
   // Wait for all threads
   // In worst case it should be no more than one thread simultaneously.
-  for(int n = 0; n<(500*2); ++n) {
+  for(int n = 0; n<(500*10); ++n) {
     sleep(1);
     if(counter >= 500) break;
   }
@@ -103,7 +108,9 @@ void ThreadTest::TestBroadcast() {
 void ThreadTest::func_wait(void* arg) {
   ThreadTest* test = (ThreadTest*)arg;
   test->cond.wait();
+  lock->lock();
   test->counter++;
+  lock->unlock();
 }
 
 void ThreadTest::func(void*) {
