@@ -1,3 +1,4 @@
+/// \cond
 /**Borrow the code about Attribute Certificate from VOMS*/
 
 /**The VOMSAttribute.h and VOMSAttribute.cpp are integration about code written by VOMS project, 
@@ -34,6 +35,9 @@
 #include <openssl/safestack.h>
 #include <openssl/err.h>
 
+#define VOMS_AC_HEADER "-----BEGIN VOMS AC-----"
+#define VOMS_AC_TRAILER "-----END VOMS AC-----"
+
 namespace ArcCredential {
 
 #define ASN1_F_D2I_AC_ATTR          5000
@@ -517,3 +521,4 @@ X509V3_EXT_METHOD * VOMSAttribute_attribs_x509v3_ext_meth();
 } // namespace ArcCredential
 
 #endif
+/// \endcond
