@@ -113,7 +113,9 @@ class DelegationConsumerSOAP: public DelegationConsumer {
  used during delegation procedure. */
 class DelegationProviderSOAP: public DelegationProvider {
  protected:
+  /** Delegation request as returned by service accepting delegations. */
   std::string request_;
+  /** Assigned delegation identifier. */
   std::string id_;
  public:
   typedef enum {
@@ -160,6 +162,13 @@ class DelegationProviderSOAP: public DelegationProvider {
      This identifier may then be used to refer to credentials stored 
      at service. */
   const std::string& ID(void) { return id_;};
+  /**
+   * Assigns identifier to be used for while initiating delegation procedure.
+   * Assigning identifier is useful only for *RENEW ServiceTypes.
+   * 
+   * \since Added in 4.1.0.
+   **/
+  void ID(const std::string& id) { id_ = id; };
 };
 
 // Implementaion of the container for delegation credentials
@@ -174,7 +183,10 @@ class DelegationContainerSOAP {
   /// Stores description of last error. Derived classes should store their errors here.
   std::string failure_;
   class Consumer;
-  typedef std::map<std::string,Consumer> ConsumerMap;
+  /**
+   * \since Changed in 4.1.0. Mapped value (Consumer) changed to pointer.
+   **/
+  typedef std::map<std::string,Consumer*> ConsumerMap;
   typedef ConsumerMap::iterator ConsumerIterator;
   ConsumerMap consumers_;
   ConsumerIterator consumers_first_;
