@@ -21,39 +21,41 @@ class BIOGSIMCC {
     MCCInterface* next_;
     unsigned int header_;
     unsigned int token_;
+    MCC_Status result_;
   public:
-    BIOGSIMCC(MCCInterface* next) { next_=next; stream_=NULL; header_=4; token_=0; };
-    BIOGSIMCC(PayloadStreamInterface* stream) { next_=NULL; stream_=stream; header_=4; token_=0; };
+    BIOGSIMCC(MCCInterface* next):result_(STATUS_OK) { next_=next; stream_=NULL; header_=4; token_=0; };
+    BIOGSIMCC(PayloadStreamInterface* stream):result_(STATUS_OK) { next_=NULL; stream_=stream; header_=4; token_=0; };
     ~BIOGSIMCC(void) { if(stream_ && next_) delete stream_; };
-    PayloadStreamInterface* Stream() { return stream_; };
+    PayloadStreamInterface* Stream() const { return stream_; };
     void Stream(PayloadStreamInterface* stream) { stream_=stream; /*free ??*/ };
-    MCCInterface* Next(void) { return next_; };
+    MCCInterface* Next(void) const { return next_; };
     void MCC(MCCInterface* next) { next_=next; };
-    int Header(void) { return header_; };
+    int Header(void) const { return header_; };
     void Header(int v) { header_=v; };
-    int Token(void) { return token_; };
+    int Token(void) const { return token_; };
     void Token(int v) { token_=v; };
+    const MCC_Status& Result(void) { return result_; };
+    static int  mcc_write(BIO *h, const char *buf, int num);
+    static int  mcc_read(BIO *h, char *buf, int size);
+    static int  mcc_puts(BIO *h, const char *str);
+    static long mcc_ctrl(BIO *h, int cmd, long arg1, void *arg2);
+    static int  mcc_new(BIO *h);
+    static int  mcc_free(BIO *data);
 };
 
-static int  mcc_write(BIO *h, const char *buf, int num);
-static int  mcc_read(BIO *h, char *buf, int size);
-static int  mcc_puts(BIO *h, const char *str);
-static long mcc_ctrl(BIO *h, int cmd, long arg1, void *arg2);
-static int  mcc_new(BIO *h);
-static int  mcc_free(BIO *data);
 
 static void BIO_set_GSIMCC(BIO* b,MCCInterface* mcc);
 static void BIO_set_GSIMCC(BIO* b,PayloadStreamInterface* stream);
 
 static BIO_METHOD methods_mcc = {
   BIO_TYPE_FD,"Message Chain Component",
-  mcc_write,
-  mcc_read,
-  mcc_puts,
+  BIOGSIMCC::mcc_write,
+  BIOGSIMCC::mcc_read,
+  BIOGSIMCC::mcc_puts,
   NULL, /* gets, */
-  mcc_ctrl,
-  mcc_new,
-  mcc_free,
+  BIOGSIMCC::mcc_ctrl,
+  BIOGSIMCC::mcc_new,
+  BIOGSIMCC::mcc_free,
   NULL,
 };
 
@@ -93,7 +95,7 @@ static void BIO_set_GSIMCC(BIO* b,PayloadStreamInterface* stream) {
   };
 }
 
-static int mcc_new(BIO *bi) {
+int BIOGSIMCC::mcc_new(BIO *bi) {
   bi->init=1;
   bi->num=0;
   bi->ptr=NULL;
@@ -101,7 +103,7 @@ static int mcc_new(BIO *bi) {
   return(1);
 }
 
-static int mcc_free(BIO *b) {
+int BIOGSIMCC::mcc_free(BIO *b) {
   if(b == NULL) return(0);
   BIOGSIMCC* biomcc = (BIOGSIMCC*)(b->ptr);
   b->ptr=NULL;
@@ -109,7 +111,7 @@ static int mcc_free(BIO *b) {
   return(1);
 }
   
-static int mcc_read(BIO *b, char *out,int outl) {
+int BIOGSIMCC::mcc_read(BIO *b, char *out,int outl) {
   int ret=0;
   if (out == NULL) return(ret);
   if(b == NULL) return(ret);
@@ -151,7 +153,7 @@ static int mcc_read(BIO *b, char *out,int outl) {
   return ret;
 }
 
-static int mcc_write(BIO *b, const char *in, int inl) {
+int BIOGSIMCC::mcc_write(BIO *b, const char *in, int inl) {
   int ret = 0;
   //clear_sys_error();
   if(in == NULL) return(ret);
@@ -208,7 +210,7 @@ static int mcc_write(BIO *b, const char *in, int inl) {
 }
 
 
-static long mcc_ctrl(BIO*, int cmd, long, void*) {
+long BIOGSIMCC::mcc_ctrl(BIO*, int cmd, long, void*) {
   long ret=0;
 
   switch (cmd) {
@@ -224,7 +226,7 @@ static long mcc_ctrl(BIO*, int cmd, long, void*) {
   return(ret);
 }
 
-static int mcc_puts(BIO *bp, const char *str) {
+int BIOGSIMCC::mcc_puts(BIO *bp, const char *str) {
   int n,ret;
 
   n=strlen(str);
@@ -232,4 +234,12 @@ static int mcc_puts(BIO *bp, const char *str) {
   return(ret);
 }
 
+bool BIO_GSIMCC_failure(BIO* bio, MCC_Status& s) {
+  if(!bio) return false;
+  BIOGSIMCC* b = (BIOGSIMCC*)(bio->ptr);
+  if(!b || b->Result()) return false;
+  s = b->Result();
+  return true;
+}
+
 } // namespace Arc
