@@ -4,7 +4,7 @@
 
 #include <openssl/ssl.h>
 
-namespace Arc {
+namespace ArcMCCTLS {
 
 std::istream* open_globus_policy(const X509_NAME* issuer_subject,const std::string& ca_path);
 bool match_globus_policy(std::istream& in,const X509_NAME* issuer_subject,const X509_NAME* subject);
