@@ -220,6 +220,7 @@ TLSSecAttr::TLSSecAttr(PayloadTLSStream& payload, ConfigTLSMCC& config, Logger&
          processing_failed_ = true; 
          logger.msg(ERROR,"VOMS attribute validation failed");
        };
+       logger.msg(ERROR,"VOMS attribute is ignored due to processing/validation error");
        v = voms_attributes_.erase(v);
      } else {
        ++v;
@@ -338,6 +339,22 @@ bool TLSSecAttr::Export(SecAttrFormat format,XMLNode &val) const {
       //add_xacml_subject_attribute(subj,target_,"http://www.nordugrid.org/schemas/policy-arc/types/tls/hostidentity");
     };
     return true;
+  } else if(format == GACL) {
+    NS ns;
+    val.Namespaces(ns); val.Name("gacl");
+    XMLNode entry = val.NewChild("entry");
+    if(!identity_.empty()) entry.NewChild("person").NewChild("dn") = identity_;
+    XMLNode voms;
+    for(std::vector<VOMSACInfo>::const_iterator v = voms_attributes_.begin();
+                                 v != voms_attributes_.end();++v) {
+      for(std::vector<std::string>::const_iterator a = v->attributes.begin();
+                                 a != v->attributes.end();++a) {
+        if(!voms) voms = entry.NewChild("voms");
+        voms.NewChild("fqan") = *a;
+      };
+      voms = XMLNode(); // ??
+    };
+    return true;
   } else {
   };
   return false;
