@@ -12,20 +12,28 @@ namespace ArcSHCLegacy {
 class LegacyPDP : public ArcSec::PDP {
  friend class LegacyPDPCP;
  private:
+  class cfgblock {
+   public:
+    std::string name;
+    std::list<std::string> groups;
+    bool exists;
+    bool limited;
+    cfgblock(const std::string& n):name(n),exists(false),limited(false) { };
+  };
   class cfgfile {
    public:
     std::string filename;
-    std::list<std::string> blocknames;
+    std::list<cfgblock> blocks;
     cfgfile(const std::string& fname):filename(fname) {};
   };
-  std::list<cfgfile> blocks_;
+  bool any_;
   std::list<std::string> groups_;
   std::list<std::string> vos_;
  public:
   static Arc::Plugin* get_pdp(Arc::PluginArgument *arg);
   LegacyPDP(Arc::Config* cfg, Arc::PluginArgument* parg);
   virtual ~LegacyPDP();
-  virtual bool isPermitted(Arc::Message *msg) const;
+  virtual ArcSec::PDPStatus isPermitted(Arc::Message *msg) const;
 };
 
 } // namespace ArcSHCLegacy
