@@ -11,11 +11,17 @@
 
 #include <glibmm.h>
 
+#include <openssl/x509.h>
+#include <openssl/evp.h>
+
 #include <gssapi.h>
+#include <globus_gsi_credential.h>
+#include <globus_gsi_cert_utils.h>
 
 #include <arc/Logger.h>
 #include <arc/Utils.h>
-#include <arc/globusutils/GSSCredential.h>
+//#include <arc/globusutils/GSSCredential.h>
+#include <arc/credential/Credential.h>
 
 #include "unixmap.h"
 
@@ -55,6 +61,22 @@ typedef void* (*getCredentialData_t)(int datatype, int *count);
 #define PRI_GID (20)
 #endif
 
+extern "C" {
+
+// Definitions taken from gssapi_openssl.h
+
+typedef struct gss_cred_id_desc_struct {
+    globus_gsi_cred_handle_t            cred_handle;
+    gss_name_t                          globusid;
+    gss_cred_usage_t                    cred_usage;
+    SSL_CTX *                           ssl_context;
+} gss_cred_id_desc;
+
+extern gss_OID_desc * gss_nt_x509;
+#define GLOBUS_GSS_C_NT_X509 gss_nt_x509
+
+};
+
 static Arc::SimpleCondition lcmaps_global_lock;
 static std::string lcmaps_db_file_old;
 static std::string lcmaps_dir_old;
@@ -81,6 +103,68 @@ void recover_lcmaps_env(void) {
   lcmaps_global_lock.unlock();
 }
 
+gss_cred_id_t read_globus_credentials(const std::string& filename) {
+  Arc::Credential cred(filename, "", "", "", "", true);
+  X509* cert = cred.GetCert();
+  STACK_OF(X509)* cchain = cred.GetCertChain();
+  EVP_PKEY* key = cred.GetPrivKey();
+  globus_gsi_cred_handle_t chandle;
+  globus_gsi_cred_handle_init(&chandle, NULL);
+  if(cert) globus_gsi_cred_set_cert(chandle, cert);
+  if(key) globus_gsi_cred_set_key(chandle, key);
+  if(cchain) globus_gsi_cred_set_cert_chain(chandle, cchain);
+
+  gss_cred_id_desc* ccred = (gss_cred_id_desc*)::malloc(sizeof(gss_cred_id_desc));
+  if(ccred) {
+    ::memset(ccred,0,sizeof(gss_cred_id_desc));
+    ccred->cred_handle = chandle; chandle = NULL;
+    // cred_usage
+    // ssl_context
+    X509* identity_cert = NULL;
+    if(cert) {
+      globus_gsi_cert_utils_cert_type_t ctype = GLOBUS_GSI_CERT_UTILS_TYPE_DEFAULT;
+      globus_gsi_cert_utils_get_cert_type(cert,&ctype);
+      if(ctype == GLOBUS_GSI_CERT_UTILS_TYPE_EEC) {
+        identity_cert = cert;
+      };
+    };
+    if(!identity_cert && cchain) {
+      // For compatibility with older globus not using
+      //globus_gsi_cert_utils_get_identity_cert(cchain,&identity_cert);
+      for(int n = 0; n < sk_X509_num(cchain); ++n) {
+        X509* tmp_cert = sk_X509_value(cchain, n);
+        if(tmp_cert) {
+          globus_gsi_cert_utils_cert_type_t ctype = GLOBUS_GSI_CERT_UTILS_TYPE_DEFAULT;
+          globus_gsi_cert_utils_get_cert_type(tmp_cert,&ctype);
+          if(ctype == GLOBUS_GSI_CERT_UTILS_TYPE_EEC) {
+            identity_cert = tmp_cert;
+            break;
+          };
+        };
+      };
+    };
+    gss_buffer_desc peer_buffer;
+    peer_buffer.value = identity_cert;
+    peer_buffer.length = identity_cert?sizeof(X509):0;
+    OM_uint32 majstat, minstat;
+    majstat = gss_import_name(&minstat, &peer_buffer,
+                              identity_cert?GLOBUS_GSS_C_NT_X509:GSS_C_NT_ANONYMOUS,
+                              &ccred->globusid);
+    if (GSS_ERROR(majstat)) {
+      logger.msg(Arc::ERROR, "Failed to convert GSI credential to "
+         "GSS credential (major: %d, minor: %d)", majstat, minstat);
+      majstat = gss_release_cred(&minstat, &ccred);
+    };
+  } else {
+    ccred = GSS_C_NO_CREDENTIAL;
+  };
+  if(cert) X509_free(cert);
+  if(key) EVP_PKEY_free(key);
+  if(cchain) sk_X509_pop_free(cchain, X509_free);
+  if(chandle) globus_gsi_cred_handle_destroy(chandle);
+  return ccred;
+}
+
 int main(int argc,char* argv[]) {
   Arc::LogStream err(std::cerr);
   err.setFormat(Arc::EmptyFormat);
@@ -160,12 +244,17 @@ int main(int argc,char* argv[]) {
     logger.msg(Arc::ERROR, "Failed to initialize LCMAPS");
     return -1;
   };
+  // In case anything is not initialized yet
+  globus_module_activate(GLOBUS_GSI_GSSAPI_MODULE);
+  globus_module_activate(GLOBUS_GSI_CREDENTIAL_MODULE);
+  globus_module_activate(GLOBUS_GSI_CERT_UTILS_MODULE);
   // User without credentials is useless for LCMAPS ?
-  Arc::GSSCredential cred(filename,"","");
+  //Arc::GSSCredential cred(filename,"","");
+  gss_cred_id_t cred = read_globus_credentials(filename);
   char* username = NULL;
   int res = 1;
   if((!getCredentialData_f) || (!lcmaps_run_f)) {
-   if((*lcmaps_run_and_return_username_f)(
+    if((*lcmaps_run_and_return_username_f)(
              (char*)(subject.c_str()),cred,(char*)"",&username,npols,policynames
        ) == 0) {
       if(username != NULL) {
@@ -219,7 +308,14 @@ int main(int argc,char* argv[]) {
   if((*lcmaps_term_f)() != 0) {
     logger.msg(Arc::WARNING, "Failed to terminate LCMAPS");
   };
+  if(cred != GSS_C_NO_CREDENTIAL) {
+    OM_uint32 majstat, minstat;
+    majstat = gss_release_cred(&minstat, &cred);
+  };
   recover_lcmaps_env();
+  globus_module_deactivate(GLOBUS_GSI_CERT_UTILS_MODULE);
+  globus_module_deactivate(GLOBUS_GSI_CREDENTIAL_MODULE);
+  globus_module_deactivate(GLOBUS_GSI_GSSAPI_MODULE);
   return res;
 }
 
