@@ -32,7 +32,7 @@ SimpleListPDP::SimpleListPDP(Config* cfg, Arc::PluginArgument* parg):PDP(cfg,par
   }
 }
 
-bool SimpleListPDP::isPermitted(Message *msg) const {
+PDPStatus SimpleListPDP::isPermitted(Message *msg) const {
   std::string subject=msg->Attributes()->get("TLS:IDENTITYDN");
   std::string line;
   if(location.empty() && dns.empty()) {
@@ -55,7 +55,7 @@ bool SimpleListPDP::isPermitted(Message *msg) const {
     return false;
   }   
 
-  while (!fs.eof()) {
+  while (fs.good()) {
     std::string::size_type p;
     getline (fs, line);
     logger.msg(DEBUG, "Policy line: %s", line);
