@@ -2,16 +2,23 @@
 #define DATADELIVERYREMOTECOMM_H_
 
 #include <arc/XMLNode.h>
-#include <arc/client/ClientInterface.h>
+#include <arc/communication/ClientInterface.h>
+#include <arc/message/MCC.h>
 
 #include "DataDeliveryComm.h"
 
 namespace DataStaging {
 
   /// This class contacts a remote service to make a Delivery request.
+  /**
+   * \ingroup datastaging
+   * \headerfile DataDeliveryRemoteComm.h arc/data-staging/DataDeliveryRemoteComm.h
+   */
   class DataDeliveryRemoteComm : public DataDeliveryComm {
   public:
+    /// Send the transfer request to the remote service.
     DataDeliveryRemoteComm(DTR_ptr dtr, const TransferParameters& params);
+    /// If transfer is still ongoing, sends a cancellation message to the service.
     virtual ~DataDeliveryRemoteComm();
 
     /// Read status from service
@@ -30,6 +37,17 @@ namespace DataStaging {
     Arc::ClientSOAP* client;
     /// Full DTR ID
     std::string dtr_full_id;
+    /// Retries allowed after failing to query transfer status, so that a
+    /// transfer is not lost due to temporary communication problem. If a
+    /// transfer fails to start it is handled by the normal DTR retries.
+    int query_retries;
+    /// MCC configuration for connecting to service
+    Arc::MCCConfig cfg;
+    /// Endpoint of remote delivery service
+    Arc::URL endpoint;
+    /// Connection timeout
+    int timeout;
+
     /// Flag to say whether transfer is running and service is still up
     bool valid;
     /// Logger object (main log, not DTR's log)
@@ -45,6 +63,9 @@ namespace DataStaging {
     /// Set up delegation so the credentials can be used by the service
     bool SetupDelegation(Arc::XMLNode& op, const Arc::UserConfig& usercfg);
 
+    /// Handle a fault during query of service. Attempts to reconnect
+    void HandleQueryFault(const std::string& err="");
+
   };
 
 } // namespace DataStaging
