@@ -13,8 +13,8 @@
 int main() {
 
   std::string jobid("123456789");
-  std::string source("http://localhost/file1");
-  std::string destination("/tmp/file1");
+  std::string source("mock://mocksrc/1");
+  std::string destination("mock://mockdest/1");
   Arc::UserConfig cfg;
 
   const int no_dtrs = 10000;
@@ -23,7 +23,7 @@ int main() {
   time_t start = time(NULL);
 
   DataStaging::DTR_ptr dtrs[no_dtrs];
-  Arc::Logger * log = NULL;
+  DataStaging::DTRLogger log = NULL;
   for(int i = 0; i<no_dtrs; ++i) {
     dtrs[i] = new DataStaging::DTR(source, destination, cfg, jobid, Arc::User().get_uid(), log);
   }
