@@ -15,7 +15,7 @@ class FileChunks {
  private:
   Glib::Mutex lock;
   FileChunksList& list;
-  std::map<std::string,FileChunks>::iterator self;
+  std::map<std::string,FileChunks*>::iterator self;
   typedef std::list<std::pair<off_t,off_t> > chunks_t;
   chunks_t chunks;
   off_t size;
@@ -38,7 +38,7 @@ class FileChunks {
   void Print(void);
   /// Release reference obtained through FileChunksList::Get() method. 
   /// This operation may lead to destruction of FileChunk instance
-  /// hence previously obtained refrence mus tnot be used.
+  /// hence previously obtained refrence must not be used.
   void Release(void);
   /// Relases reference obtained through Get() method and destroys its instance.
   /// Normally this method to be called instead of Release() after whole 
@@ -52,7 +52,7 @@ class FileChunksList {
  friend class FileChunks;
  private:
   Glib::Mutex lock;
-  typedef std::map<std::string,FileChunks> files_t;
+  typedef std::map<std::string,FileChunks*> files_t;
   files_t files;
   int timeout;
   time_t last_timeout;
