@@ -1,3 +1,6 @@
+#ifndef __ARC_DELEGATION_STORES_H__
+#define __ARC_DELEGATION_STORES_H__
+
 #include <string>
 #include <map>
 
@@ -36,3 +39,5 @@ class DelegationStores {
 
 } // namespace ARex
 
+#endif // __ARC_DELEGATION_STORE_H__
+
