@@ -27,6 +27,7 @@ namespace ARex {
 #define HARD_JOB_PERIOD 7200
 
 /* cache cleaning every 5 minutes */
+
 #define CACHE_CLEAN_PERIOD 300
 
 /* cache cleaning default timeout */
@@ -61,17 +62,20 @@ static void cache_func(void* arg) {
   std::vector<std::string> cache_info_dirs = cache_info.getCacheDirs();
   if (cache_info_dirs.empty()) return;
 
-  // in arc.conf % of used space is given, but cache-clean uses % of free space
-  std::string minfreespace = Arc::tostring(100-cache_info.getCacheMax());
-  std::string maxfreespace = Arc::tostring(100-cache_info.getCacheMin());
+  std::string maxusedspace = Arc::tostring(cache_info.getCacheMax());
+  std::string minusedspace = Arc::tostring(cache_info.getCacheMin());
   std::string cachelifetime = cache_info.getLifeTime();
   std::string logfile = cache_info.getLogFile();
+  bool cacheshared = cache_info.getCacheShared();
+  std::string cachespacetool = cache_info.getCacheSpaceTool();
 
   // do cache-clean -h for explanation of options
   std::string cmd = Arc::ArcLocation::GetToolsDir() + "/cache-clean";
-  cmd += " -m " + minfreespace;
-  cmd += " -M " + maxfreespace;
+  cmd += " -m " + minusedspace;
+  cmd += " -M " + maxusedspace;
   if (!cachelifetime.empty()) cmd += " -E " + cachelifetime;
+  if (cacheshared) cmd += " -S ";
+  if (!cachespacetool.empty()) cmd += " -f \"" + cachespacetool + "\" ";
   cmd += " -D " + cache_info.getLogLevel();
   for (std::vector<std::string>::iterator i = cache_info_dirs.begin(); i != cache_info_dirs.end(); i++) {
     cmd += " " + (i->substr(0, i->find(" ")));
@@ -268,17 +272,15 @@ bool GridManager::thread() {
   jobs.RestartJobs();
 
   hard_job_time = time(NULL) + HARD_JOB_PERIOD;
-  if (config_.UseDTR()) {
-    logger.msg(Arc::INFO, "Starting data staging threads");
-    DTRGenerator* dtr_generator = new DTRGenerator(config_, &kick_func, wakeup_);
-    if (!(*dtr_generator)) {
-      delete dtr_generator;
-      logger.msg(Arc::ERROR, "Failed to start data staging threads, exiting Grid Manager thread");
-      return false;
-    }
-    dtr_generator_ = dtr_generator;
-    jobs.SetDataGenerator(dtr_generator);
+  logger.msg(Arc::INFO, "Starting data staging threads");
+  DTRGenerator* dtr_generator = new DTRGenerator(config_, &kick_func, wakeup_);
+  if (!(*dtr_generator)) {
+    delete dtr_generator;
+    logger.msg(Arc::ERROR, "Failed to start data staging threads, exiting Grid Manager thread");
+    return false;
   }
+  dtr_generator_ = dtr_generator;
+  jobs.SetDataGenerator(dtr_generator);
   bool scan_old = false;
   std::string heartbeat_file("gm-heartbeat");
   Arc::WatchdogChannel wd(config_.WakeupPeriod()*3+300);
