@@ -653,8 +653,9 @@ bool DTRGenerator::processReceivedJob(const GMJob& job) {
   else if (job.get_state() == JOB_STATE_FINISHING) {
     files = output_files;
     std::list<FileData>::iterator it;
-    // add any output files dynamically added by the user during the job
-    for (it = files.begin(); it != files.end() ; ++it) {
+    // add any output files dynamically added by the user during the job and
+    // resolve directories
+    for (it = files.begin(); it != files.end() ;) {
       if (it->pfn.find("@") == 1) { // GM puts a slash on the front of the local file
         std::string outputfilelist = job.SessionDir() + std::string("/") + it->pfn.substr(2);
         logger.msg(Arc::INFO, "%s: Reading output files from user generated list in %s", jobid, outputfilelist);
@@ -673,7 +674,48 @@ bool DTRGenerator::processReceivedJob(const GMJob& job) {
           return false;
         }
         it->pfn.erase(1, 1);
+        ++it;
+        continue;
       }
+      if (it->pfn.rfind('/') == it->pfn.length()-1) {
+        if (it->lfn.find(':') != std::string::npos) {
+          std::string cred(it->cred);
+          std::string dir(job.SessionDir() + it->pfn);
+          std::list<std::string> entries;
+          if (!Arc::DirList(dir, entries, true, job_uid, job_gid)) {
+            logger.msg(Arc::ERROR, "%s: Failed to list output directory %s: %s", jobid, dir, Arc::StrError(errno));
+            lock.lock();
+            // Only write this failure if no previous failure
+            if (job.GetFailure(config).empty()) {
+              finished_jobs[jobid] = std::string("Failed to list output directory");
+            } else {
+              finished_jobs[jobid] = "";
+            }
+            lock.unlock();
+            CleanCacheJobLinks(config, job);
+            if (kicker_func) (*kicker_func)(kicker_arg);
+            return false;
+          }
+          // add entries which are not directories or links to output file list
+          struct stat st;
+          for (std::list<std::string>::iterator i = entries.begin(); i != entries.end(); ++i) {
+            if (Arc::FileStat(*i, &st, job_uid, job_gid, false) && S_ISREG(st.st_mode)) {
+              std::string lfn(it->lfn + '/' + i->substr(job.SessionDir().length()+it->pfn.length()));
+              std::string pfn(i->substr(job.SessionDir().length()));
+              logger.msg(Arc::DEBUG, "%s: Adding new output file %s: %s", jobid, pfn, lfn);
+              FileData fd(pfn, lfn);
+              fd.cred = cred;
+              files.push_back(fd);
+            }
+          }
+          it = files.erase(it);
+          continue;
+        }
+        // Remove trailing slashes otherwise it will be cleaned in delete_all_files
+        std::string::size_type pos = it->pfn.find_last_not_of('/');
+        it->pfn.resize((pos == std::string::npos)?1:(pos+1));
+      }
+      ++it;
     }
     // check if any files share the same LFN, if so allow overwriting existing LFN
     for (it = files.begin(); it != files.end(); it++) {
@@ -767,11 +809,12 @@ bool DTRGenerator::processReceivedJob(const GMJob& job) {
     if (job.get_state() == JOB_STATE_PREPARING) {
       // If ACIX should be used, use it as source and add original URL as
       // location after DTR is created
-      if (!config.ACIXEndpoint().empty()) {
-        // Encode the original url so it is not parsed as part of the acix url
+      // If cache=check then don't use remote caches as the copy must be up to date
+      Arc::URL original_url(i->lfn);
+      if (!staging_conf.get_acix_endpoint().empty() && original_url.Option("cache") != "check") {
         original_source = i->lfn;
-        Arc::URL acix_source(config.ACIXEndpoint() + "?url=" + Arc::uri_encode(original_source, false));
-        Arc::URL original_url(original_source);
+        // Encode the original url so it is not parsed as part of the acix url
+        Arc::URL acix_source(staging_conf.get_acix_endpoint() + "?url=" + Arc::uri_encode(original_source, false));
         // Add URL options to ACIX URL
         for (std::map<std::string, std::string>::const_iterator opt = original_url.Options().begin();
              opt != original_url.Options().end(); ++opt) {
@@ -809,7 +852,15 @@ bool DTRGenerator::processReceivedJob(const GMJob& job) {
         ++file;
       }
     }
-
+    // Add common purpose URL options from configuration
+    {
+      Arc::URL u(source);
+      if (u) {
+        u.AddOption("httpgetpartial", staging_conf.get_httpgetpartial()?"yes":"no", false);
+        // Consider adding passive and secure here
+        source = u.fullstr();
+      }
+    }
     std::string proxy_cred;
     if(!i->cred.empty()) {
       usercfg.ProxyPath(i->cred);
@@ -841,6 +892,7 @@ bool DTRGenerator::processReceivedJob(const GMJob& job) {
     // set real location if ACIX is used
     if (!original_source.empty()) {
       dtr->get_source()->AddLocation(Arc::URL(original_source), Arc::URL(original_source).ConnectionURL());
+      dtr->set_use_acix(true);
     }
 
     DataStaging::DTRCacheParameters cache_parameters;
