@@ -232,7 +232,7 @@ int main(int argc,char** argv) {
         passive=true;
       }; break;
       case 'd': {
-        Arc::Logger::getRootLogger().setThreshold(Arc::string_to_level(optarg));
+        Arc::Logger::getRootLogger().setThreshold(Arc::istring_to_level(optarg));
       }; break;
       case 'r': {
         // not relevant for uploader
