@@ -1,10 +1,15 @@
 #ifndef __ARC_GM_SEND_MAIL_H__
 #define __ARC_GM_SEND_MAIL_H__
+
+namespace ARex {
+
 /*
   Starts external process smtp-send.sh to send mail to user
   about changes in job's status.
 */
-bool send_mail(const JobDescription &desc,JobUser &user);
+bool send_mail(const GMJob &job, const GMConfig& config);
+
+} // namespace ARex
 
 #endif
 
