@@ -206,12 +206,14 @@ sub condor_grep_nodes {
 #   3 (Removed)    --> E (finishing in the LRMS)
 #   4 (Completed)  --> E (finishing in the LRMS)
 #   5 (Held)       --> O (other)
+#   6 (Transfer)   --> O (other, almost finished. Transferring output.)
+#   7 (Suspended)  --> S (newer condor version support suspended)
 #
 # If the job couldn't be found, E is returned since it is probably finished.
 #
 sub condor_get_job_status($) {
     my $id = shift;
-    my %num2letter = qw(1 Q 2 R 3 E 4 E 5 O);
+    my %num2letter = qw(1 Q 2 R 3 E 4 E 5 O 6 O 7 S);
     return 'E' unless $alljobdata{$id};
     my $s = $alljobdata{$id}{jobstatus};
     return 'E' if !defined $s;
@@ -270,7 +272,7 @@ sub condor_queue_get_queued() {
 sub condor_cluster_get_queued_cpus() {
     my $sum = 0;
     do {$sum++ if $$_{jobstatus} == 1 || $$_{jobstatus} == 5} for values %alljobdata;
-    debug "===condor_cluster_get_queued: $sum";
+    debug "===condor_cluster_get_queued_cpus: $sum";
     return $sum;
 }
 
@@ -280,17 +282,20 @@ sub condor_cluster_get_queued_cpus() {
 sub condor_cluster_get_queued_jobs() {
     my $sum = 0;
     do {$sum++ if $$_{jobstatus} == 1 || $$_{jobstatus} == 5} for values %alljobdata;
-    debug "===condor_cluster_get_queued: $sum";
+    debug "===condor_cluster_get_queued_jobs: $sum";
     return $sum;
 }
 
 #
 # Counts all running jobs in the cluster.
 # TODO: also counts suspended jobs apparently.
+# only counts suspended jobs in earlier versions of Condor
+# Newer versions have separate state (7) for supended jobs
+
 sub condor_cluster_get_running_jobs() {
     my $sum = 0;
     do {$sum++ if $$_{jobstatus} == 2} for values %alljobdata;
-    debug "===condor_cluster_get_queued: $sum";
+    debug "===condor_cluster_get_running_jobs: $sum";
     return $sum;
 }
 
@@ -542,7 +547,7 @@ sub jobs_info ($$@) {
             $lrms_jobs{$id}{mem} = $job{lc 'ImageSize'};
             $lrms_jobs{$id}{walltime} = floor($job{lc 'RemoteWallClockTime'} / 60);
             $lrms_jobs{$id}{cputime} = floor(($job{lc 'RemoteUserCpu'} + $job{lc 'RemoteSysCpu'}) / 60);
-            $lrms_jobs{$id}{nodes} = "";
+            $lrms_jobs{$id}{nodes} = [];
             $lrms_jobs{$id}{nodes} = [$job{lc 'LastRemoteHost'}] if ($job{lc 'LastRemoteHost'} ne "undefined");
             $lrms_jobs{$id}{nodes} = [$job{lc 'RemoteHost'}] if ($job{lc 'RemoteHost'} ne "undefined");
             if ($job{lc 'JobTimeLimit'} ne "undefined") {
