@@ -84,6 +84,7 @@ my $share_options = {
     Preemption => '*',
     totalcpus => '*',
     defaultmemory => '*',
+    authorizedvo =>  [ '*' ],
 };
 my $gmuser_options = {
     controldir => '',
@@ -125,7 +126,9 @@ my $ldap_infosys_options = {
     infosys_glue2_ldap => '*',
     bdii_update_pid_file => '*',
     infosys_glue2_ldap_showactivities => '*',
-    infosys_glue2_service_qualitylevel => '*'
+    infosys_glue2_service_qualitylevel => '*',
+    infoproviders_timeout => '*',
+    validity_ttl => '*'
 };
 my $gridftpd_options = {
     GridftpdEnabled => '*',
