@@ -15,6 +15,9 @@ use English;
 use File::Basename;
 use File::Temp qw(tempfile tempdir);
 use File::Path qw(mkpath);
+#use Data::Dumper::Concise;
+## usage:
+# print Dumper($datastructure); 
 
 use LogUtils;
 
@@ -50,6 +53,8 @@ sub uidGidFromFile {
 
 #
 # switch effective user if possible. This is reversible.
+# It switches back to root if the passed parameter
+# is 0.
 #
 sub switchEffectiveUser {
     my ($uid) = @_;
@@ -59,7 +64,12 @@ sub switchEffectiveUser {
         eval { $EGID = $gid;
                $EUID = $uid;
         };
-    }
+    # Switch back to original UID/GID
+	} else {
+		eval { $EGID = $GID;
+               $EUID = $UID;
+        };
+    };
 }
 
 #
@@ -340,4 +350,77 @@ sub ldifIsReady {
     return 1;
 }
 
+#
+# infosys heartbeat simply implemented using a file
+# input: config datastructure
+#
+sub heartbeatBeat {
+    my ($config) = @_;
+    # complicated to use run dir. Reverted to controldir
+    # TODO: with better configuration settings, there should be only
+    # one run dir.
+    #my ($infosys_ldap_run_dir) = findInfosys($config);
+    #my $heartbeatFileName = $infosys_ldap_run_dir.'/infosys_heartbeat';
+    my $controldir = $config->{'control'}->{'.'}->{'controldir'};
+    my $heartbeatFileName = $controldir.'/infosys_heartbeat';
+    
+    # set drift to 20 seconds before timeout
+    my $infoproviders_timeout_drift = 60;
+    #my $heartbeatFileName = '/tmp/infosys_heartbeat';
+    
+    # check if heartbeat file exists, if not create it
+    my $mtime = (stat($heartbeatFileName))[9];
+    if ( !( defined $mtime ) ) {
+		$log->debug("Creating heartbeat file $heartbeatFileName");
+        local (*HB);
+        open (HB, ">>$heartbeatFileName") || $log->error("Failed creating heartbeat file $heartbeatFileName. Check if controldir is writable");
+        close (HB);
+    } else {
+        # touch if file exists, every minute.
+	    my $now = time;
+	    my $drift = $now - $mtime;
+	    $log->debug("Heartbeat file mtime: $mtime now: $now drift: $drift infoprov_timeout_drift: $infoproviders_timeout_drift");
+	    if ($drift > $infoproviders_timeout_drift) {
+			$log->debug("Touching heartbeat file: last touch more than 60 sec.");
+			unless (utime $now, $now, $heartbeatFileName) { $log->error("Failed touching heartbeat file $heartbeatFileName. Check if controldir is writable"); };
+			$log->verbose("Touching heartbeat file $heartbeatFileName successful");
+		} else {
+	        $log->debug("Skipping heartbeat: less than 60 sec since last touch.");     
+	    }
+	}
+}
+
+#
+# Delete the heartbeat file.
+# input: configuration datastructure
+#
+sub heartbeatRemove {
+    my ($config) = @_;
+    # see comment above on controldir choice.
+    my $controldir = $config->{'control'}->{'.'}->{'controldir'};
+    my $heartbeatFileName = $controldir.'/infosys_heartbeat';
+    
+	unlink $heartbeatFileName or $log->warning("Could not unlink $heartbeatFileName: $!");
+	$log->verbose("Removing hearbeat file $heartbeatFileName");
+}
+
+#
+# Parametrized versions of heartbeat that expects controldir and timeout.
+# To use in infoproviders to avoid passing the whole config
+# input: controldir path
+#
+sub heartbeatBeatParam {
+	my ($controldir) = @_;
+	my $fakeconfig = {};
+	$fakeconfig->{'control'}->{'.'}->{'controldir'} = $controldir;
+	heartbeatBeat($fakeconfig);
+}
+
+sub heartbeatRemoveParam {
+	my ($controldir) = @_;
+	my $fakeconfig = {};
+	$fakeconfig->{'control'}->{'.'}->{'controldir'} = $controldir;
+	heartbeatRemove($fakeconfig);
+}
+	
 1;
