@@ -374,6 +374,17 @@ ARexJob::ARexJob(Arc::XMLNode jsdl,ARexGMConfig& config,const std::string& crede
     return;
   };
   std::string cred = credentials;
+  if(cred.empty()) {
+    // If job comes through EMI-ES it has delegations assigned only per file through source and target.
+    // But ARC has extension to pass global delegation for whole DataStaging.
+    if(!desc.DataStaging.DelegationID.empty()) {
+      std::string path = (*deleg)[config_.GmConfig().DelegationDir()].
+                                FindCred(desc.DataStaging.DelegationID,config_.GridName());
+      if(!path.empty()) {
+        Arc::FileRead(path, cred);
+      }
+    }
+  }
   if(cred.empty()) {
     // If job comes through EMI-ES it has delegations assigned per file.
     // But special dynamic output files @list have no targets and no delegations.
@@ -382,7 +393,7 @@ ARexJob::ARexJob(Arc::XMLNode jsdl,ARexGMConfig& config,const std::string& crede
                                                  f != desc.DataStaging.OutputFiles.end();++f) {
       if(f->Name[0] == '@') {
         // dynamic file
-        // It should be error here. But cirrent workaround is to try to use
+        // It should be error here. But current workaround is to try to use
         // any of provided delegations.
         need_delegation = true; 
         break;
