@@ -12,6 +12,7 @@
 #include <arc/win32.h>
 #endif
 
+#include "Reporter.h"
 #include "Destinations.h"
 
 namespace Arc
@@ -20,7 +21,7 @@ namespace Arc
    *  of the given control directory, and reports usage data extracted from 
    *  job log files within.
    */
-  class UsageReporter
+  class UsageReporter:public Reporter
   {
   private:
     Arc::Logger logger;
