@@ -8,21 +8,26 @@
 #include <arc/XMLNode.h>
 #include <string>
 
-#include "../a-rex/grid-manager/jobs/users.h"
+// A-REX include for GM configuration
+#include "../a-rex/grid-manager/conf/GMConfig.h"
+
+#include "CacheServiceGenerator.h"
 
 namespace Cache {
 
 /**
  * CacheService provides functionality for A-REX cache operations that can be
- * performed by remote clients. It currently consists of two operations:
+ * performed by remote clients. It currently consists of three operations:
  * CacheCheck - allows querying of the cache for the presence of files.
  * CacheLink - enables a running job to dynamically request cache files to
- * be linked to its working (session) directory. This is especially useful
- * in the case of pilot job workflows where job submission does not follow
- * the usual ARC workflow. In order for input files to be available to jobs,
- * the pilot job can call the cache service to prepare them. If requested files
- * are not present in the cache, they can be downloaded by the cache service
- * if requested, using the A-REX downloader utility.
+ * be linked to its working (session) directory.
+ * CacheLinkQuery - query the status of a transfer initiated by CacheLink.
+ * This service is especially useful in the case of pilot job workflows where
+ * job submission does not follow the usual ARC workflow. In order for input
+ * files to be available to jobs, the pilot job can call the cache service to
+ * prepare them. If requested files are not present in the cache, they can be
+ * downloaded by the cache service if requested, using the DTR data staging
+ * framework.
  */
 class CacheService: public Arc::RegisteredService {
 
@@ -30,66 +35,49 @@ class CacheService: public Arc::RegisteredService {
   /** Return codes of cache link */
   enum CacheLinkReturnCode {
     Success,                 // everything went ok
+    Staging,                 // files are still in the middle of downloading
     NotAvailable,            // cache file doesn't exist and dostage is false
     Locked,                  // cache file is locked (being downloaded by other process)
     CacheError,              // error with cache (configuration, filesystem etc)
     PermissionError,         // user doesn't have permission on original source
     LinkError,               // error while linking to session dir
     DownloadError,           // error downloading cache file
-    TooManyDownloadsError    // current number of downloads exceeds limit
   };
   /** Construct a SOAP error message with optional extra reason string */
   Arc::MCC_Status make_soap_fault(Arc::Message& outmsg, const std::string& reason = "");
   /** CacheService namespace */
   Arc::NS ns;
-  /** Download limit read from cache service configuration */
-  unsigned int max_downloads;
-  /** Current downloads - using gint to guarantee atomic thread-safe operations */
-  gint current_downloads;
-  /** Users read from A-REX configuration */
-  JobUsers* users;
-  /** Holds environment state, eg config files etc */
-  GMEnvironment* gm_env;
-  /** Configuration information, held by reference inside gm_env so must
-      not be deleted before it. */
-  JobsListConfig* jcfg;
+  /** A-REX configuration */
+  ARex::GMConfig config;
+  /** Generator to handle data staging */
+  CacheServiceGenerator* dtr_generator;
   /** Logger object */
   static Arc::Logger logger;
 
-  /** Launch a download process for the given URLs
-   * @param urls A map of (remote file, local filename relative to session
-   * dir) which gives sources and destinations for transfer
-   * @param user A-REX user configuration for the mapped user
-   * @param job_id ID of the job
-   * @param mapped_user The local user to which the client DN was mapped
-   * @return -1 if an error occurred outside the downloader process, or
-   * the return code of the downloader process.
-   */
-  int Download(const std::map<std::string, std::string>& urls,
-               const JobUser& user,
-               const std::string& job_id,
-               const Arc::User& mapped_user);
-
  protected:
   /* Cache operations */
   /**
    * Check whether the URLs supplied in the input are present in any cache.
    * Returns in the out message for each file true or false, and if true,
    * the size of the file on cache disk.
-   * @param user A-REX user configuration for the mapped user
+   * @param mapped_user The local user to which the client DN was mapped
    */
-  Arc::MCC_Status CacheCheck(Arc::XMLNode in, Arc::XMLNode out, const JobUser& user);
+  Arc::MCC_Status CacheCheck(Arc::XMLNode in, Arc::XMLNode out, const Arc::User& mapped_user);
   /**
    * This method is used to link cache files to the session dir. A list of
    * URLs is supplied and if they are present in the cache and the user
    * calling the service has permission to access them, then they are linked
    * to the given session directory. If the user requests that missing files
-   * be staged, then a downloader process is launched to obtain them.
-   * @param user A-REX user configuration for the mapped user
+   * be staged, then data staging requests are entered. The user should then
+   * use CacheLinkQuery to poll the status of the requests.
    * @param mapped_user The local user to which the client DN was mapped
    */
-  Arc::MCC_Status CacheLink(Arc::XMLNode in, Arc::XMLNode out,
-                            const JobUser& user, const Arc::User& mapped_user);
+  Arc::MCC_Status CacheLink(Arc::XMLNode in, Arc::XMLNode out, const Arc::User& mapped_user);
+
+  /**
+   * Query the status of data staging for a given job ID.
+   */
+  Arc::MCC_Status CacheLinkQuery(Arc::XMLNode in, Arc::XMLNode out);
 
  public:
   /**
@@ -104,7 +92,7 @@ class CacheService: public Arc::RegisteredService {
   /**
    * Main method called by HED when CacheService is invoked. Directs call
    * to appropriate CacheService method.
-   * */
+   */
   virtual Arc::MCC_Status process(Arc::Message &inmsg, Arc::Message &outmsg);
   /**
    * Supplies information on the service for use in the information system.
