@@ -233,6 +233,7 @@ struct voms AuthUser::arc_to_voms(const std::string& vo,const std::vector<std::s
 
   struct voms voms_item;
   voms_item.voname = vo;
+  voms_item.fqans = attributes;
   // For matching against pure VO
   voms_item.attrs.push_back(voms_attrs());
   for(std::vector<std::string>::const_iterator v = attributes.begin(); v != attributes.end(); ++v) {
@@ -318,6 +319,10 @@ const std::list<std::string>& AuthUser::VOs(void) const {
 }
 
 bool AuthUser::add_vo(const char* vo,const char* filename) {
+  if((!filename) || (!filename[0])) {
+    logger.msg(Arc::WARNING,"The [vo] section labeled '%s' has no file associated and can't be used for matching", vo);
+    return false;
+  }
   if(match_file(filename) == AAA_POSITIVE_MATCH) {
     add_vo(vo);
     return true;
