@@ -9,7 +9,7 @@
 
 namespace gridftpd {
 
-  int config_vo(AuthUser& user,ConfigSections& sect,std::string& cmd,std::string& rest) {
+  int config_vo(AuthUser& user,ConfigSections& sect,std::string& cmd,std::string& rest,Arc::Logger* logger) {
     if(strcmp(sect.SectionMatch(),"vo") != 0) return 1;
     if(cmd.length() == 0) return 1;
     std::string voname = sect.SubSection();
@@ -22,7 +22,9 @@ namespace gridftpd {
       };
       sect.ReadNext(cmd,rest);
       if(sect.SectionNew() || (cmd.length() == 0)) {
-        if(voname.length() && vofile.length()) {
+        if(voname.empty()) {
+          logger->msg(Arc::WARNING, "Configuration section [vo] is missing name. Check for presence of name= or vo= option.");
+        } else {
           user.add_vo(voname,vofile);
         };
         if(cmd.length() == 0) return 1;
@@ -33,7 +35,7 @@ namespace gridftpd {
     return 0;
   }
 
-  int config_vo(std::list<AuthVO>& vos,ConfigSections& sect,std::string& cmd,std::string& rest) {
+  int config_vo(std::list<AuthVO>& vos,ConfigSections& sect,std::string& cmd,std::string& rest,Arc::Logger* logger) {
     if(strcmp(sect.SectionMatch(),"vo") != 0) return 1;
     if(cmd.length() == 0) return 1;
     std::string voname = sect.SubSection();
@@ -46,7 +48,9 @@ namespace gridftpd {
       };
       sect.ReadNext(cmd,rest);
       if(sect.SectionNew() || (cmd.length() == 0)) {
-        if(voname.length() && vofile.length()) {
+        if(voname.empty()) {
+          logger->msg(Arc::WARNING, "Configuration section [vo] is missing name. Check for presence of name= or vo= option.");
+        } else {
           vos.push_back(AuthVO(voname,vofile));
         };
         if(cmd.length() == 0) return 1;
@@ -58,38 +62,40 @@ namespace gridftpd {
   }
 
   // vo name filename etc.
-  int config_vo(AuthUser& user,const std::string& cmd,std::string& rest) {
+  int config_vo(AuthUser& user,const std::string& cmd,std::string& rest,Arc::Logger* logger) {
     if(cmd != "vo") return 1;
     std::string voname = config_next_arg(rest);
     std::string vofile = config_next_arg(rest);
-    if((voname.length() == 0) || (vofile.length() == 0)) {
+    if(voname.empty()) {
+      logger->msg(Arc::WARNING, "Configuration section [vo] is missing name. Check for presence of name= or vo= option.");
       return -1;
     };
     user.add_vo(voname,vofile);
     return 0;
   }
 
-  int config_vo(std::list<AuthVO>& vos,const std::string& cmd,std::string& rest) {
+  int config_vo(std::list<AuthVO>& vos,const std::string& cmd,std::string& rest,Arc::Logger* logger) {
     if(cmd != "vo") return 1;
     std::string voname = config_next_arg(rest);
     std::string vofile = config_next_arg(rest);
-    if((voname.length() == 0) || (vofile.length() == 0)) {
+    if(voname.empty()) {
+      logger->msg(Arc::WARNING, "Configuration section [vo] is missing name. Check for presence of name= or vo= option.");
       return -1;
     };
     vos.push_back(AuthVO(voname,vofile));
     return 0;
   }
 
-  int config_vo(AuthUser& user,const char* cmd,const char* rest) {
+  int config_vo(AuthUser& user,const char* cmd,const char* rest,Arc::Logger* logger) {
     std::string cmd_(cmd);
     std::string rest_(rest);
-    return config_vo(user,cmd_,rest_);
+    return config_vo(user,cmd_,rest_,logger);
   }
 
-  int config_vo(std::list<AuthVO>& vos,const char* cmd,const char* rest) {
+  int config_vo(std::list<AuthVO>& vos,const char* cmd,const char* rest,Arc::Logger* logger) {
     std::string cmd_(cmd);
     std::string rest_(rest);
-    return config_vo(vos,cmd_,rest_);
+    return config_vo(vos,cmd_,rest_,logger);
   }
 
 } // namespace gridftpd
