@@ -15,7 +15,7 @@ namespace gridftpd {
   bool file_user_list(const std::string& path,std::string &ulist) {
     std::ifstream f(path.c_str());
     if(! f.is_open() ) return false;
-    for(;!(f.eof() || f.fail());) {
+    for(;f.good();) {
       std::string rest;
       std::getline(f,rest);
       Arc::trim(rest," \t\r\n");
@@ -41,7 +41,7 @@ namespace gridftpd {
   bool file_user_list(const std::string& path,std::list<std::string> &ulist) {
     std::ifstream f(path.c_str());
     if(! f.is_open() ) return false;
-    for(;!(f.eof() || f.fail());) {
+    for(;f.good();) {
       std::string rest;
       std::getline(f,rest);
       Arc::trim(rest," \t\r\n");
